#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkDoubleArray
from vtkmodules.vtkCommonDataModel import vtkCellArray
from vtkmodules.vtkFiltersCore import (
    vtkConstrainedSmoothingFilter,
    vtkExecutionTimer,
)
from vtkmodules.vtkFiltersSources import vtkPlaneSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2

# Test edge smoothing of meshes with specified smoothing stencils, and
# user-defined smoothing stencils.

# Control the resolution of the tests.
#res = 200
res = 4

# Create a x-y plane
plane = vtkPlaneSource()
plane.SetResolution(res,res)
plane.SetOrigin(0,0,0)
plane.SetPoint1(1,0,0)
plane.SetPoint2(0,1,0)
plane.Update()

# Create a constraint array
constraints = vtkDoubleArray()
constraints.SetName("SmoothingConstraints")
numPts = plane.GetOutput().GetNumberOfPoints()
constraints.SetNumberOfTuples(numPts)
for i in range(0,numPts):
    constraints.SetTuple1(i,1000)
constraints.SetTuple1(0,0.0)
constraints.SetTuple1(res,0.0)
constraints.SetTuple1(numPts-res-1,0.0)
constraints.SetTuple1(numPts-1,0.0)

output = plane.GetOutput()
output.GetPointData().AddArray(constraints)

# Manually create smoothing stencils
stencils = vtkCellArray()
pts = [0,0,0,0]
pts = [1,5]
stencils.InsertNextCell(2,pts) #stencil for point 0
pts = [0,2,6]
stencils.InsertNextCell(3,pts) #stencil for point 1
pts = [1,3,7]
stencils.InsertNextCell(3,pts) #stencil for point 2
pts = [2,4,8]
stencils.InsertNextCell(3,pts) #stencil for point 3
pts = [3,9]
stencils.InsertNextCell(2,pts) #stencil for point 4
pts = [0,6,10]
stencils.InsertNextCell(3,pts) #stencil for point 5
pts = [1,7,11,5]
stencils.InsertNextCell(4,pts) #stencil for point 6
pts = [2,8,12,6]
stencils.InsertNextCell(4,pts) #stencil for point 7
pts = [3,9,13,7]
stencils.InsertNextCell(4,pts) #stencil for point 8
pts = [4,8,14]
stencils.InsertNextCell(3,pts) #stencil for point 9
pts = [5,11,15]
stencils.InsertNextCell(3,pts) #stencil for point 10
pts = [6,12,16,10]
stencils.InsertNextCell(4,pts) #stencil for point 11
pts = [7,13,17,11]
stencils.InsertNextCell(4,pts) #stencil for point 12
pts = [8,14,18,12]
stencils.InsertNextCell(4,pts) #stencil for point 13
pts = [9,13,19]
stencils.InsertNextCell(3,pts) #stencil for point 14
pts = [10,16,20]
stencils.InsertNextCell(3,pts) #stencil for point 15
pts = [11,17,21,15]
stencils.InsertNextCell(4,pts) #stencil for point 16
pts = [12,18,22,16]
stencils.InsertNextCell(4,pts) #stencil for point 17
pts = [13,19,23,17]
stencils.InsertNextCell(4,pts) #stencil for point 18
pts = [14,18,24]
stencils.InsertNextCell(3,pts) #stencil for point 19
pts = [15,21]
stencils.InsertNextCell(2,pts) #stencil for point 20
pts = [20,16,22]
stencils.InsertNextCell(3,pts) #stencil for point 21
pts = [21,17,23]
stencils.InsertNextCell(3,pts) #stencil for point 22
pts = [22,18,24]
stencils.InsertNextCell(3,pts) #stencil for point 23
pts = [19,23]
stencils.InsertNextCell(2,pts) #stencil for point 24

# Now smooth the mesh with a filter constraint
smooth = vtkConstrainedSmoothingFilter()
smooth.SetInputConnection(plane.GetOutputPort())
smooth.SetSmoothingStencils(stencils)
smooth.SetConstraintStrategyToConstraintDistance()
smooth.SetConstraintDistance(0.1)
smooth.SetNumberOfIterations(100)
smooth.SetRelaxationFactor(.2)
smooth.GenerateErrorScalarsOn()
smooth.GenerateErrorVectorsOff()

timer = vtkExecutionTimer()
timer.SetFilter(smooth)
smooth.Update()
ST = timer.GetElapsedWallClockTime()
print ("Smooth Edges: ", ST)

smoothMapper = vtkPolyDataMapper()
smoothMapper.SetInputConnection(smooth.GetOutputPort())
smoothMapper.ScalarVisibilityOn()

smoothActor = vtkActor()
smoothActor.SetMapper(smoothMapper)
smoothActor.GetProperty().SetInterpolationToFlat()

# Use a constraint array
smooth2 = vtkConstrainedSmoothingFilter()
smooth2.SetInputConnection(plane.GetOutputPort())
smooth2.SetSmoothingStencils(stencils)
smooth2.SetConstraintStrategyToConstraintArray()
smooth2.SetNumberOfIterations(100)
smooth2.SetRelaxationFactor(.2)
smooth2.GenerateErrorScalarsOn()
smooth2.GenerateErrorVectorsOn()

timer.SetFilter(smooth2)
smooth2.Update()
ST = timer.GetElapsedWallClockTime()
print ("Smooth Edges (constraint array): ", ST)

# Color by scalar errors if scalar visibility is enabled.
# We don't enable it here because different rendering libraries
# will shade quads differently.
smooth2Mapper = vtkPolyDataMapper()
smooth2Mapper.SetInputConnection(smooth2.GetOutputPort())
smooth2Mapper.ScalarVisibilityOff()
smooth2Mapper.SetScalarModeToUsePointFieldData()
smooth2Mapper.SelectColorArray("SmoothingErrorScalars")
smooth2Mapper.SetScalarRange(smooth2.GetOutput().GetPointData().GetArray("SmoothingErrorScalars").GetRange())

smooth2Actor = vtkActor()
smooth2Actor.SetMapper(smooth2Mapper)
smooth2Actor.GetProperty().SetInterpolationToFlat()

# Define graphics objects
renWin = vtkRenderWindow()
renWin.SetSize(600,300)

ren1 = vtkRenderer()
ren1.SetViewport(0,0,0.5,1)
ren1.SetBackground(0,0,0)

ren2 = vtkRenderer()
ren2.SetViewport(0.5,0,1,1)
ren2.SetBackground(0,0,0)

renWin.AddRenderer(ren1)
renWin.AddRenderer(ren2)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren1.AddActor(smoothActor)
ren2.AddActor(smooth2Actor)
ren1.ResetCamera()
ren2.SetActiveCamera(ren1.GetActiveCamera())
renWin.Render()

iren.Initialize()
iren.Start()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkLookupTable
from vtkmodules.vtkCommonDataModel import vtkSphere
from vtkmodules.vtkIOImage import (
    vtkBMPReader,
    vtkPNMReader,
)
from vtkmodules.vtkImagingCore import (
    vtkImageBlend,
    vtkImageTranslateExtent,
)
from vtkmodules.vtkImagingStencil import vtkImplicitFunctionToImageStencil
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# do alpha-blending of two images, but also clip with stencil
reader1 = vtkBMPReader()
reader1.SetFileName(VTK_DATA_ROOT + "/Data/masonry.bmp")

reader2 = vtkPNMReader()
reader2.SetFileName(VTK_DATA_ROOT + "/Data/B.pgm")

table = vtkLookupTable()
table.SetTableRange(0, 127)
table.SetValueRange(0.0, 1.0)
table.SetSaturationRange(0.0, 0.0)
table.SetHueRange(0.0, 0.0)
table.SetAlphaRange(0.9, 0.0)
table.Build()

translate = vtkImageTranslateExtent()
translate.SetInputConnection(reader2.GetOutputPort())
translate.SetTranslation(60, 60, 0)

sphere = vtkSphere()
sphere.SetCenter(121, 131, 0)
sphere.SetRadius(70)

functionToStencil = vtkImplicitFunctionToImageStencil()
functionToStencil.SetInput(sphere)

blend = vtkImageBlend()
blend.SetInputConnection(reader1.GetOutputPort())
blend.AddInputConnection(translate.GetOutputPort())

# exercise the ReplaceNthInputConnection method
blend.ReplaceNthInputConnection(1, reader1.GetOutputPort())
blend.ReplaceNthInputConnection(1, translate.GetOutputPort())
blend.SetOpacity(1, 0.8)
blend.SetStencilConnection(functionToStencil.GetOutputPort())

viewer = vtkImageViewer()
viewer.SetInputConnection(blend.GetOutputPort())
viewer.SetColorWindow(255.0)
viewer.SetColorLevel(127.5)
viewer.SetZSlice(0)
viewer.Render()



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkMath,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import vtkPolyData
from vtkmodules.vtkFiltersCore import vtkThreshold
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersPoints import (
    vtkMaskPointsFilter,
    vtkPointOccupancyFilter,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# The resolution of the masking volume
res = 15

# Parameters for debugging
math = vtkMath()
math.RandomSeed(31415)

# create pipeline
#
# A set of points at the extreme positions
pts = vtkPoints()
pts.SetNumberOfPoints(9)
pts.SetPoint(0, 0,0,0)
pts.SetPoint(1, -1,-1,-1)
pts.SetPoint(2,  1,-1,-1)
pts.SetPoint(3, -1, 1,-1)
pts.SetPoint(4,  1, 1,-1)
pts.SetPoint(5, -1,-1, 1)
pts.SetPoint(6,  1,-1, 1)
pts.SetPoint(7, -1, 1, 1)
pts.SetPoint(8,  1, 1, 1)

ptsPD = vtkPolyData()
ptsPD.SetPoints(pts);

# Generate occupancy mask
occ = vtkPointOccupancyFilter()
occ.SetInputData(ptsPD)
occ.SetSampleDimensions(res,res+2,res+4)
occ.SetOccupiedValue(255)

# Display the result: outline plus surface
outline = vtkOutlineFilter()
outline.SetInputConnection(occ.GetOutputPort())

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper);

surface = vtkThreshold()
surface.SetInputConnection(occ.GetOutputPort())
surface.SetThresholdFunction(vtkThreshold.THRESHOLD_UPPER)
surface.SetUpperThreshold(1.0)
surface.AllScalarsOff()

surfaceMapper = vtkDataSetMapper()
surfaceMapper.SetInputConnection(surface.GetOutputPort())
surfaceMapper.ScalarVisibilityOff()

surfaceActor = vtkActor()
surfaceActor.SetMapper(surfaceMapper);

points = vtkMaskPointsFilter()
points.SetInputData(ptsPD)
points.SetMaskConnection(occ.GetOutputPort())
points.GenerateVerticesOn()

pointsMapper = vtkPolyDataMapper()
pointsMapper.SetInputConnection(points.GetOutputPort())

pointsActor = vtkActor()
pointsActor.SetMapper(pointsMapper);
pointsActor.GetProperty().SetPointSize(3)
pointsActor.GetProperty().SetColor(0,1,0)

# Create the RenderWindow, Renderer and both Actors
#
ren0 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Add the actors to the renderer, set the background and size
#
#ren0.AddActor(outlineActor)
ren0.AddActor(surfaceActor)
#ren0.AddActor(pointsActor)
ren0.SetBackground(0,0,0)

renWin.SetSize(300,300)

cam = ren0.GetActiveCamera()
cam.SetFocalPoint(0,0,0)
cam.SetPosition(1,1,1)
ren0.ResetCamera()

iren.Initialize()

# render the image
#
renWin.Render()

iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import vtkStructuredGrid
from vtkmodules.vtkFiltersCore import vtkCellDataToPointData
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# cell scalars to point scalars
# get the interactor ui
# Create the RenderWindow, Renderer and RenderWindowInteractor
ren1 = vtkRenderer(background=[0.1, 0.2, 0.4])
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# create a 2*2 cell/3*3 pt structuredgrid
points = vtkPoints()
for pt in [(-1,1,0), (0,1,0), (1,1,0), (-1,0,0),
           (0,0,0), (1,0,0), (-1,-1,0), (0,-1,0),
           (1,-1,0)]:
    points.InsertNextPoint(pt)
faceColors = vtkFloatArray()
for val in (0, 1, 1, 2):
    faceColors.InsertNextValue(val)
sgrid = vtkStructuredGrid(dimensions=(3,3,1))
sgrid.points = points
sgrid.GetCellData().SetScalars(faceColors)
Cell2Point = vtkCellDataToPointData(pass_cell_data=True)
mapper = vtkDataSetMapper()
mapper.SetScalarModeToUsePointData()
mapper.SetScalarRange(0,2)
sgrid >> Cell2Point >> mapper
actor = vtkActor(mapper=mapper)
# Add the actors to the renderer, set the background and size
ren1.AddActor(actor)
renWin.SetSize(256,256)
# render the image
iren.Initialize()
# --- end of script --



#!/usr/bin/env python
# -*- coding: utf-8 -*-



from vtkmodules.vtkCommonCore import vtkLookupTable
from vtkmodules.vtkCommonDataModel import (
    vtkPiecewiseFunction,
    vtkPlane,
)
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersCore import (
    vtkMarchingCubes,
    vtkPolyDataNormals,
    vtkStripper,
)
from vtkmodules.vtkFiltersSources import vtkConeSource
from vtkmodules.vtkIOImage import vtkVolume16Reader
from vtkmodules.vtkImagingCore import vtkImageMapToColors
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkColorTransferFunction,
    vtkDataSetMapper,
    vtkImageSlice,
    vtkImageSliceMapper,
    vtkPolyDataMapper,
    vtkProperty,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkVolume,
    vtkVolumeProperty,
)
from vtkmodules.vtkRenderingVolume import (
    vtkFixedPointVolumeRayCastMapper,
    vtkVolumePicker,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.vtkRenderingVolumeOpenGL2
import vtkmodules.test.Testing
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

class VolumePicker(vtkmodules.test.Testing.vtkTest):

    def testVolumePicker(self):
        # volume render a medical data set

        # renderer and interactor
        ren = vtkRenderer()

        renWin = vtkRenderWindow()
        renWin.AddRenderer(ren)

        iRen = vtkRenderWindowInteractor()
        iRen.SetRenderWindow(renWin)

        # read the volume
        v16 = vtkVolume16Reader()
        v16.SetDataDimensions(64, 64)
        v16.SetImageRange(1, 93)
        v16.SetDataByteOrderToLittleEndian()
        v16.SetFilePrefix(VTK_DATA_ROOT + "/Data/headsq/quarter")
        v16.SetDataSpacing(3.2, 3.2, 1.5)

        #---------------------------------------------------------
        # set up the volume rendering

        volumeMapper = vtkFixedPointVolumeRayCastMapper()
        volumeMapper.SetInputConnection(v16.GetOutputPort())

        volumeColor = vtkColorTransferFunction()
        volumeColor.AddRGBPoint(0, 0.0, 0.0, 0.0)
        volumeColor.AddRGBPoint(180, 0.3, 0.1, 0.2)
        volumeColor.AddRGBPoint(1000, 1.0, 0.7, 0.6)
        volumeColor.AddRGBPoint(2000, 1.0, 1.0, 0.9)

        volumeScalarOpacity = vtkPiecewiseFunction()
        volumeScalarOpacity.AddPoint(0, 0.0)
        volumeScalarOpacity.AddPoint(180, 0.0)
        volumeScalarOpacity.AddPoint(1000, 0.2)
        volumeScalarOpacity.AddPoint(2000, 0.8)

        volumeGradientOpacity = vtkPiecewiseFunction()
        volumeGradientOpacity.AddPoint(0, 0.0)
        volumeGradientOpacity.AddPoint(90, 0.5)
        volumeGradientOpacity.AddPoint(100, 1.0)

        volumeProperty = vtkVolumeProperty()
        volumeProperty.SetColor(volumeColor)
        volumeProperty.SetScalarOpacity(volumeScalarOpacity)
        volumeProperty.SetGradientOpacity(volumeGradientOpacity)
        volumeProperty.SetInterpolationTypeToLinear()
        volumeProperty.ShadeOn()
        volumeProperty.SetAmbient(0.6)
        volumeProperty.SetDiffuse(0.6)
        volumeProperty.SetSpecular(0.1)

        volume = vtkVolume()
        volume.SetMapper(volumeMapper)
        volume.SetProperty(volumeProperty)

        #---------------------------------------------------------
        # Do the surface rendering
        boneExtractor = vtkMarchingCubes()
        boneExtractor.SetInputConnection(v16.GetOutputPort())
        boneExtractor.SetValue(0, 1150)

        boneNormals = vtkPolyDataNormals()
        boneNormals.SetInputConnection(boneExtractor.GetOutputPort())
        boneNormals.SetFeatureAngle(60.0)

        boneStripper = vtkStripper()
        boneStripper.SetInputConnection(boneNormals.GetOutputPort())

        boneMapper = vtkPolyDataMapper()
        boneMapper.SetInputConnection(boneStripper.GetOutputPort())
        boneMapper.ScalarVisibilityOff()

        boneProperty = vtkProperty()
        boneProperty.SetColor(1.0, 1.0, 0.9)

        bone = vtkActor()
        bone.SetMapper(boneMapper)
        bone.SetProperty(boneProperty)

        #---------------------------------------------------------
        # Create an image actor

        table = vtkLookupTable()
        table.SetRange(0, 2000)
        table.SetRampToLinear()
        table.SetValueRange(0, 1)
        table.SetHueRange(0, 0)
        table.SetSaturationRange(0, 0)

        mapToColors = vtkImageMapToColors()
        mapToColors.SetInputConnection(v16.GetOutputPort())
        mapToColors.SetLookupTable(table)

        imageMapper = vtkImageSliceMapper()
        imageMapper.SetInputConnection(mapToColors.GetOutputPort())
        imageMapper.SetOrientationToX()
        imageMapper.SetSliceNumber(32)

        imageActor = vtkImageSlice()
        imageActor.SetMapper(imageMapper)

        #---------------------------------------------------------
        # make a transform and some clipping planes

        transform = vtkTransform()
        transform.RotateWXYZ(-20, 0.0, -0.7, 0.7)

        volume.SetUserTransform(transform)
        bone.SetUserTransform(transform)
        imageActor.SetUserTransform(transform)

        c = volume.GetCenter()

        volumeClip = vtkPlane()
        volumeClip.SetNormal(0, 1, 0)
        volumeClip.SetOrigin(c)

        boneClip = vtkPlane()
        boneClip.SetNormal(0, 0, 1)
        boneClip.SetOrigin(c)

        volumeMapper.AddClippingPlane(volumeClip)
        boneMapper.AddClippingPlane(boneClip)

        #---------------------------------------------------------
        ren.AddViewProp(volume)
        ren.AddViewProp(bone)
        ren.AddViewProp(imageActor)

        camera = ren.GetActiveCamera()
        camera.SetFocalPoint(c)
        camera.SetPosition(c[0] + 500, c[1] - 100, c[2] - 100)
        camera.SetViewUp(0, 0, -1)

        ren.ResetCameraClippingRange()

        renWin.Render()

        #---------------------------------------------------------
        # the cone should point along the Z axis
        coneSource = vtkConeSource()
        coneSource.CappingOn()
        coneSource.SetHeight(12)
        coneSource.SetRadius(5)
        coneSource.SetResolution(31)
        coneSource.SetCenter(6, 0, 0)
        coneSource.SetDirection(-1, 0, 0)

        #---------------------------------------------------------
        picker = vtkVolumePicker()
        picker.SetTolerance(1.0e-6)
        picker.SetVolumeOpacityIsovalue(0.01)
        # This should usually be left alone, but is used here to increase coverage
        picker.UseVolumeGradientOpacityOn()

        # A function to point an actor along a vector
        def PointCone(actor, n):
            if n[0] < 0.0:
                actor.RotateWXYZ(180, 0, 1, 0)
                actor.RotateWXYZ(180, (n[0] - 1.0) * 0.5, n[1] * 0.5, n[2] * 0.5)
            else:
                actor.RotateWXYZ(180, (n[0] + 1.0) * 0.5, n[1] * 0.5, n[2] * 0.5)

        # Pick the actor
        picker.Pick(192, 103, 0, ren)
        #print picker
        p = picker.GetPickPosition()
        n = picker.GetPickNormal()

        coneActor1 = vtkActor()
        coneActor1.PickableOff()
        coneMapper1 = vtkDataSetMapper()
        coneMapper1.SetInputConnection(coneSource.GetOutputPort())
        coneActor1.SetMapper(coneMapper1)
        coneActor1.GetProperty().SetColor(1, 0, 0)
        coneActor1.SetPosition(p)
        PointCone(coneActor1, n)
        ren.AddViewProp(coneActor1)

        # Pick the volume
        picker.Pick(90, 180, 0, ren)
        p = picker.GetPickPosition()
        n = picker.GetPickNormal()

        coneActor2 = vtkActor()
        coneActor2.PickableOff()
        coneMapper2 = vtkDataSetMapper()
        coneMapper2.SetInputConnection(coneSource.GetOutputPort())
        coneActor2.SetMapper(coneMapper2)
        coneActor2.GetProperty().SetColor(1, 0, 0)
        coneActor2.SetPosition(p)
        PointCone(coneActor2, n)
        ren.AddViewProp(coneActor2)

        # Pick the image
        picker.Pick(200, 200, 0, ren)
        p = picker.GetPickPosition()
        n = picker.GetPickNormal()

        coneActor3 = vtkActor()
        coneActor3.PickableOff()
        coneMapper3 = vtkDataSetMapper()
        coneMapper3.SetInputConnection(coneSource.GetOutputPort())
        coneActor3.SetMapper(coneMapper3)
        coneActor3.GetProperty().SetColor(1, 0, 0)
        coneActor3.SetPosition(p)
        PointCone(coneActor3, n)
        ren.AddViewProp(coneActor3)

        # Pick a clipping plane
        picker.PickClippingPlanesOn()
        picker.Pick(145, 160, 0, ren)
        p = picker.GetPickPosition()
        n = picker.GetPickNormal()

        coneActor4 = vtkActor()
        coneActor4.PickableOff()
        coneMapper4 = vtkDataSetMapper()
        coneMapper4.SetInputConnection(coneSource.GetOutputPort())
        coneActor4.SetMapper(coneMapper4)
        coneActor4.GetProperty().SetColor(1, 0, 0)
        coneActor4.SetPosition(p)
        PointCone(coneActor4, n)
        ren.AddViewProp(coneActor4)

        ren.ResetCameraClippingRange()

        # render and interact with data

        renWin.Render()

        img_file = "VolumePicker.png"
        vtkmodules.test.Testing.compareImage(iRen.GetRenderWindow(), vtkmodules.test.Testing.getAbsImagePath(img_file))
        vtkmodules.test.Testing.interact()

if __name__ == "__main__":
     vtkmodules.test.Testing.main([(VolumePicker, 'test')])



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkMath
from vtkmodules.vtkCommonSystem import vtkTimerLog
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersPoints import (
    vtkBoundedPointSource,
    vtkVoxelGrid,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPointGaussianMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Interpolate onto a volume

# Parameters for debugging
NPts = 1000000
math = vtkMath()
math.RandomSeed(31415)

# create pipeline
#
points = vtkBoundedPointSource()
points.SetNumberOfPoints(NPts)
points.ProduceRandomScalarsOn()
points.ProduceCellOutputOff()
points.Update()

# Subsample
subsample = vtkVoxelGrid()
subsample.SetInputConnection(points.GetOutputPort())
subsample.SetConfigurationStyleToManual()
subsample.SetDivisions(47,47,47)

# Time execution
timer = vtkTimerLog()
timer.StartTimer()
subsample.Update()
timer.StopTimer()
time = timer.GetElapsedTime()
print("Time to subsample: {0}".format(time))
print("   Number of divisions: {}".format(subsample.GetDivisions()))
print("   Original number of points: {0}".format(NPts))
print("   Final number of points: {0}".format(subsample.GetOutput().GetNumberOfPoints()))

# Output the original points
subMapper = vtkPointGaussianMapper()
subMapper.SetInputConnection(points.GetOutputPort())
subMapper.EmissiveOff()
subMapper.SetScaleFactor(0.0)

subActor = vtkActor()
subActor.SetMapper(subMapper)

# Create an outline
outline = vtkOutlineFilter()
outline.SetInputConnection(points.GetOutputPort())

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)

# Output the subsampled points
subMapper1 = vtkPointGaussianMapper()
subMapper1.SetInputConnection(subsample.GetOutputPort())
subMapper1.EmissiveOff()
subMapper1.SetScaleFactor(0.0)

subActor1 = vtkActor()
subActor1.SetMapper(subMapper1)

# Create an outline
outline1 = vtkOutlineFilter()
outline1.SetInputConnection(points.GetOutputPort())

outlineMapper1 = vtkPolyDataMapper()
outlineMapper1.SetInputConnection(outline1.GetOutputPort())

outlineActor1 = vtkActor()
outlineActor1.SetMapper(outlineMapper1)

# Create the RenderWindow, Renderer and both Actors
#
ren0 = vtkRenderer()
ren0.SetViewport(0,0,.5,1)
ren1 = vtkRenderer()
ren1.SetViewport(0.5,0,1,1)
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Add the actors to the renderer, set the background and size
#
ren0.AddActor(subActor)
ren0.AddActor(outlineActor)
ren0.SetBackground(0.1, 0.2, 0.4)

ren1.AddActor(subActor1)
ren1.AddActor(outlineActor1)
ren1.SetBackground(0.1, 0.2, 0.4)

renWin.SetSize(500,250)

cam = ren0.GetActiveCamera()
cam.SetFocalPoint(0,0,0)
cam.SetPosition(1,1,1)
ren0.ResetCamera()

ren1.SetActiveCamera(cam)

iren.Initialize()

# render the image
#
renWin.Render()

iren.Start()



from vtkmodules.vtkFiltersSources import vtkRandomHyperTreeGridSource
from vtkmodules.vtkIOXML import (
    vtkXMLHyperTreeGridReader,
    vtkXMLHyperTreeGridWriter,
)

# Creating pseudo-random HTG source
source = vtkRandomHyperTreeGridSource()
source.SetDimensions(5, 5, 2)
source.SetSeed(3713971)
source.SetSplitFraction(0.75);

name = "output_TestWriteReadRandomHTGAppendBinaryMode1.htg"

# Creating HTG Writer
writer = vtkXMLHyperTreeGridWriter()
writer.SetInputConnection(source.GetOutputPort())
writer.SetDataSetMajorVersion(1)
writer.SetDataModeToAppended()
writer.SetFileName( name )
print("Writing HTG to {}".format(name))
writer.Update()

# Creating HTG Reader
reader = vtkXMLHyperTreeGridReader()
reader.SetFileName( name )
print("Reading HTG from {}".format(name))
reader.Update()



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkLookupTable
from vtkmodules.vtkCommonExecutionModel import vtkCastToConcrete
from vtkmodules.vtkFiltersCore import (
    vtkElevationFilter,
    vtkPolyDataNormals,
)
from vtkmodules.vtkFiltersGeneral import vtkWarpScalar
from vtkmodules.vtkFiltersGeometry import vtkImageDataGeometryFilter
from vtkmodules.vtkImagingCore import vtkImageShrink3D
from vtkmodules.vtkIOImage import vtkDEMReader
from vtkmodules.vtkRenderingCore import (
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
from vtkmodules.vtkRenderingLOD import vtkLODActor
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

Scale = 5

lut = vtkLookupTable()
lut.SetHueRange(0.6, 0)
lut.SetSaturationRange(1.0, 0)
lut.SetValueRange(0.5, 1.0)

demModel = vtkDEMReader()
demModel.SetFileName(VTK_DATA_ROOT + "/Data/SainteHelens.dem")
demModel.Update()

lo = Scale * demModel.GetElevationBounds()[0]
hi = Scale * demModel.GetElevationBounds()[1]
demActor = vtkLODActor()

# create a pipeline for each lod mapper
lods = ["4", "8", "16"]
for lod in lods:
    exec("shrink" + lod + " = vtkImageShrink3D()")
    eval("shrink" + lod).SetShrinkFactors(int(lod), int(lod), 1)
    eval("shrink" + lod).SetInputConnection(demModel.GetOutputPort())
    eval("shrink" + lod).AveragingOn()

    exec("geom" + lod + " = vtkImageDataGeometryFilter()")
    eval("geom" + lod).SetInputConnection(eval("shrink" + lod).GetOutputPort())
    eval("geom" + lod).ReleaseDataFlagOn()

    exec("warp" + lod + " = vtkWarpScalar()")
    eval("warp" + lod).SetInputConnection(eval("geom" + lod).GetOutputPort())
    eval("warp" + lod).SetNormal(0, 0, 1)
    eval("warp" + lod).UseNormalOn()
    eval("warp" + lod).SetScaleFactor(Scale)
    eval("warp" + lod).ReleaseDataFlagOn()

    exec("elevation" + lod + " = vtkElevationFilter()")
    eval("elevation" + lod).SetInputConnection(
      eval("warp" + lod).GetOutputPort())
    eval("elevation" + lod).SetLowPoint(0, 0, lo)
    eval("elevation" + lod).SetHighPoint(0, 0, hi)
    eval("elevation" + lod).SetScalarRange(lo, hi)
    eval("elevation" + lod).ReleaseDataFlagOn()

    exec("toPoly" + lod + " = vtkCastToConcrete()")
    eval("toPoly" + lod).SetInputConnection(
      eval("elevation" + lod).GetOutputPort())

    exec("normals" + lod + "  = vtkPolyDataNormals()")
    eval("normals" + lod).SetInputConnection(
      eval("toPoly" + lod).GetOutputPort())
    eval("normals" + lod).SetFeatureAngle(60)
    eval("normals" + lod).ConsistencyOff()
    eval("normals" + lod).SplittingOff()
    eval("normals" + lod).ReleaseDataFlagOn()

    exec("demMapper" + lod + "  = vtkPolyDataMapper()")
    eval("demMapper" + lod).SetInputConnection(
      eval("normals" + lod).GetOutputPort())
    eval("demMapper" + lod).SetScalarRange(lo, hi)
    eval("demMapper" + lod).SetLookupTable(lut)
    eval("demMapper" + lod).Update()

    demActor.AddLODMapper(eval("demMapper" + lod))

# Add the actors to the renderer, set the background and size
#
ren1.AddActor(demActor)
ren1.SetBackground(.4, .4, .4)
iren.SetDesiredUpdateRate(1)

def TkCheckAbort(obj=None, event=""):
    if renWin.GetEventPending():
        renWin.SetAbortRender(1)

renWin.AddObserver("AbortCheckEvent", TkCheckAbort)

ren1.GetActiveCamera().SetViewUp(0, 0, 1)
ren1.GetActiveCamera().SetPosition(-99900, -21354, 131801)
ren1.GetActiveCamera().SetFocalPoint(41461, 41461, 2815)
ren1.ResetCamera()
ren1.GetActiveCamera().Dolly(1.2)
ren1.ResetCameraClippingRange()

renWin.Render()

#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkIOGeometry import vtkGAMBITReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Read some Fluent GAMBIT in ASCII form
reader = vtkGAMBITReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/prism.neu")
mapper = vtkDataSetMapper()
mapper.SetInputConnection(reader.GetOutputPort())
actor = vtkActor()
actor.SetMapper(mapper)
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# Add the actors to the renderer, set the background and size
#
ren1.AddActor(actor)
renWin.SetSize(300,300)
iren.Initialize()
renWin.Render()
# prevent the tk window from showing up then start the event loop
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    reference,
    vtkPoints,
)
from vtkmodules.vtkCommonColor import vtkNamedColors
from vtkmodules.vtkCommonDataModel import (
    vtkCellArray,
    vtkPolyData,
    vtkStaticCellLocator,
)
from vtkmodules.vtkFiltersCore import vtkGlyph3D
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# retrieve named colors
def GetRGBColor(colorName):
    '''
        Return the red, green and blue components for a
        color as doubles.
    '''
    rgb = [0.0, 0.0, 0.0]  # black
    vtkNamedColors().GetColorRGB(colorName, rgb)
    return rgb

# Control resolution of test (sphere resolution)
res = 9

# Create the RenderWindow, Renderer
#
ren = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer( ren )

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create pipeline. Two spheres: one is the target to
# be intersected against, and is placed inside a static
# cell locator. The second bounds these, it's points
# serve as starting points that shoot rays towards the
# center of the fist sphere.
#
sphere = vtkSphereSource()
sphere.SetThetaResolution(2*res)
sphere.SetPhiResolution(res)
sphere.Update()

mapper = vtkPolyDataMapper()
mapper.SetInputConnection(sphere.GetOutputPort())

actor = vtkActor()
actor.SetMapper(mapper)

# Now the locator
loc = vtkStaticCellLocator()
loc.SetDataSet(sphere.GetOutput())
loc.SetNumberOfCellsPerNode(5)
loc.BuildLocator()

locPD = vtkPolyData()
loc.GenerateRepresentation(4,locPD)
locMapper = vtkPolyDataMapper()
locMapper.SetInputData(locPD)
locActor = vtkActor()
locActor.SetMapper(locMapper)
locActor.GetProperty().SetRepresentationToWireframe()

# Now the outer sphere
sphere2 = vtkSphereSource()
sphere2.SetThetaResolution(res)
sphere2.SetPhiResolution(int(res/2))
sphere2.SetRadius(3*sphere.GetRadius())
sphere2.Update()

# Generate intersection points
center = sphere.GetCenter()
polyInts = vtkPolyData()
pts = vtkPoints()
spherePts = sphere2.GetOutput().GetPoints()
numRays = spherePts.GetNumberOfPoints()
pts.SetNumberOfPoints(numRays + 1)

polyRays = vtkPolyData()
rayPts = vtkPoints()
rayPts.SetNumberOfPoints(numRays + 1)
lines = vtkCellArray()

t = reference(0.0)
subId = reference(0)
cellId = reference(0)
xyz = [0.0,0.0,0.0]
xInt = [0.0,0.0,0.0]
pc = [0.0,0.0,0.0]

pts.SetPoint(0,center)
rayPts.SetPoint(0,center)
for i in range(0, numRays):
    spherePts.GetPoint(i,xyz)
    rayPts.SetPoint(i+1,xyz)
    cellId = reference(i);
    hit = loc.IntersectWithLine(xyz, center, 0.001, t, xInt, pc, subId, cellId)
    if ( hit == 0 ):
        print("Missed: {}".format(i))
        pts.SetPoint(i+1,center)
    else:
        pts.SetPoint(i+1,xInt)
    lines.InsertNextCell(2)
    lines.InsertCellPoint(0)
    lines.InsertCellPoint(i+1)

polyInts.SetPoints(pts)

polyRays.SetPoints(rayPts)
polyRays.SetLines(lines)

# Glyph the intersection points
glyphSphere = vtkSphereSource()
glyphSphere.SetPhiResolution(6)
glyphSphere.SetThetaResolution(12)

glypher = vtkGlyph3D()
glypher.SetInputData(polyInts)
glypher.SetSourceConnection(glyphSphere.GetOutputPort())
glypher.SetScaleFactor(0.05)

glyphMapper = vtkPolyDataMapper()
glyphMapper.SetInputConnection(glypher.GetOutputPort())

glyphActor = vtkActor()
glyphActor.SetMapper(glyphMapper)
glyphActor.GetProperty().SetColor(GetRGBColor('peacock'))

linesMapper = vtkPolyDataMapper()
linesMapper.SetInputData(polyRays)

linesActor = vtkActor()
linesActor.SetMapper(linesMapper)
linesActor.GetProperty().SetColor(GetRGBColor('tomato'))

# Render it
ren.AddActor(actor)
ren.AddActor(glyphActor)
ren.AddActor(locActor)
ren.AddActor(linesActor)

ren.GetActiveCamera().SetPosition(1,1,1)
ren.GetActiveCamera().SetFocalPoint(0,0,0)
ren.ResetCamera()

renWin.Render()
iren.Start()



#!/usr/bin/env python

# This script tests the vtkDistanceToCamera algorithm
# The left renderer (dark background) shows polydata
# colored homogeneously.
# The right renderer (light background) shows unstructured
# grid colored inhomogeneously as defined by the 'values'
# array.
# Zooming in and out in each renderer will change the color
# of the hexahedron.
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    VTK_HEXAHEDRON,
    vtkCellArray,
    vtkPolyData,
    vtkUnstructuredGrid,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkDistanceToCamera,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

pts = vtkPoints()
values = vtkFloatArray()
values.SetName('values')
for z in [0,1]:
  for y in [0,1]:
    for x in [0,1]:
      pid = pts.InsertNextPoint(x*2,y*3,z*4)

pointdata = [-1,-2,-2,-1,1,2,2,1]
for v in pointdata:
  values.InsertNextValue( v )

linecells = [[0,1],[1,3],[3,2],[2,0],[4,5],[5,7],[7,6],[6,4],[0,4],[1,5],[2,6],[3,7]]
quadcells = [[0,1,3,2],[4,5,7,6],[0,1,5,4],[1,3,7,5],[3,2,6,7],[0,2,6,4]]
hexacells = [[0,1,3,2,4,5,7,6]]

# Set up the polydata based pipeline
poly = vtkPolyData()
poly.SetPoints(pts)
poly.GetPointData().SetScalars(values)
verts = vtkCellArray()
for cell in quadcells:
  verts.InsertNextCell(len(cell))
  for p in cell:
    verts.InsertCellPoint(p)
#poly.SetVerts(verts)
lines = vtkCellArray()
for cell in linecells:
  lines.InsertNextCell(len(cell))
  for p in cell:
    lines.InsertCellPoint(p)
#poly.SetLines(lines)
quads = vtkCellArray()
for cell in quadcells:
  quads.InsertNextCell(len(cell))
  for p in cell:
    quads.InsertCellPoint(p)
poly.SetPolys(quads)
polyD2C = vtkDistanceToCamera()
polyD2C.SetInputData(poly)
polyMapper = vtkPolyDataMapper()
polyMapper.SetInputConnection(polyD2C.GetOutputPort())
polyMapper.SetScalarModeToUsePointFieldData()
polyMapper.SelectColorArray('DistanceToCamera')
polyActor = vtkActor()
polyActor.SetMapper(polyMapper)
polyRenderer = vtkRenderer()
polyRenderer.AddViewProp(polyActor)
polyRenderer.SetBackground(.2,.2,.2)
polyRenderer.SetViewport(0.,0.,0.5,1.0)
polyD2C.SetRenderer(polyRenderer)
polyRenderer.GetActiveCamera().SetFocalPoint(1,1.5,2)
polyRenderer.GetActiveCamera().SetPosition(-2,-4,6)
polyRenderer.ResetCamera()

# Set up the unstructured grid based pipeline
ug = vtkUnstructuredGrid()
ug.SetPoints(pts)
for cell in hexacells:
  ug.InsertNextCell(VTK_HEXAHEDRON,len(cell),cell)
ug.GetPointData().SetScalars(values)
ugD2C = vtkDistanceToCamera()
ugD2C.SetInputData(ug)
ugD2C.SetDistanceArrayName('d2c')
ugD2C.ScalingOn()
ugD2C.SetInputArrayToProcess(0,0,0,0,'values')
ugMapper = vtkDataSetMapper()
ugMapper.SetInputConnection(ugD2C.GetOutputPort())
ugMapper.SetScalarModeToUsePointFieldData()
ugMapper.SelectColorArray('d2c')
ugActor = vtkActor()
ugActor.SetMapper(ugMapper)
ugRenderer = vtkRenderer()
ugRenderer.AddViewProp(ugActor)
ugRenderer.SetBackground(.4,.4,.4)
ugRenderer.SetViewport(0.5,0.,1.0,1.0)
ugD2C.SetRenderer(ugRenderer)
ugRenderer.GetActiveCamera().SetFocalPoint(1,1.5,2)
ugRenderer.GetActiveCamera().SetPosition(-2,-4,6)
ugRenderer.ResetCamera()

# Render both
renWin = vtkRenderWindow()
renWin.SetSize(600,300)
renWin.AddRenderer(polyRenderer)
renWin.AddRenderer(ugRenderer)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Test zoomed out
ugRenderer.GetActiveCamera().Zoom(0.3)
polyRenderer.GetActiveCamera().Zoom(0.3)
iren.Render()

#iren.Start()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonSystem import vtkTimerLog
from vtkmodules.vtkFiltersCore import vtkElevationFilter
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPointGaussianMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkRendererSource,
)
from vtkmodules.vtkRenderingImage import vtkDepthImageToPointCloud
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Parameters for testing
sze = 300

# Graphics stuff
ren0 = vtkRenderer()
ren0.SetViewport(0,0,0.5,1)
ren1 = vtkRenderer()
ren1.SetViewport(0.5,0,1,1)
renWin = vtkRenderWindow()
renWin.SetSize(2*sze+100,sze)
renWin.AddRenderer(ren0)
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create pipeline, render simple object. We'll also color
# the sphere to generate color scalars.
sphere = vtkSphereSource()
sphere.SetCenter(0,0,0)
sphere.SetRadius(1)

ele = vtkElevationFilter()
ele.SetInputConnection(sphere.GetOutputPort())
ele.SetLowPoint(0,-1,0)
ele.SetHighPoint(0,1,0)

sphereMapper = vtkPolyDataMapper()
sphereMapper.SetInputConnection(ele.GetOutputPort())

sphereActor = vtkActor()
sphereActor.SetMapper(sphereMapper)

ren0.AddActor(sphereActor)
ren0.SetBackground(0,0,0)

iren.Initialize()
ren0.ResetCamera()
ren0.GetActiveCamera().SetClippingRange(6,9)
renWin.Render()

# Extract rendered geometry, convert to point cloud
# Grab just z-values
renSource = vtkRendererSource()
renSource.SetInput(ren0)
renSource.WholeWindowOff()
renSource.DepthValuesOnlyOn()
renSource.Update()

# Grab color values
renSource1 = vtkRendererSource()
renSource1.SetInput(ren0)
renSource1.WholeWindowOff()
renSource1.DepthValuesOff()
renSource1.DepthValuesInScalarsOff()
renSource1.Update()

# Note that the vtkPointGaussianMapper does not require vertex cells
pc = vtkDepthImageToPointCloud()
pc.SetInputConnection(0,renSource.GetOutputPort())
pc.SetInputConnection(1,renSource1.GetOutputPort())
pc.SetCamera(ren0.GetActiveCamera())
pc.CullNearPointsOn()
pc.CullFarPointsOn()
pc.ProduceVertexCellArrayOff()
print(pc)

timer = vtkTimerLog()
timer.StartTimer()
pc.Update()
timer.StopTimer()
time = timer.GetElapsedTime()
print("Generate point cloud: {0}".format(time))

pcMapper = vtkPointGaussianMapper()
pcMapper.SetInputConnection(pc.GetOutputPort())
pcMapper.EmissiveOff()
pcMapper.SetScaleFactor(0.0)

pcActor = vtkActor()
pcActor.SetMapper(pcMapper)

ren1.AddActor(pcActor)
ren1.SetBackground(0,0,0)
cam = ren1.GetActiveCamera()
cam.SetFocalPoint(0,0,0)
cam.SetPosition(1,1,1)
ren1.ResetCamera()

renWin.Render()
#iren.Start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-



from vtkmodules.vtkCommonColor import vtkNamedColors
from vtkmodules.vtkFiltersCore import vtkSynchronizedTemplates3D
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkIOLegacy import vtkStructuredPointsReader
from vtkmodules.vtkImagingCore import (
    vtkImageCast,
    vtkImageClip,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.test.Testing
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()



class sync3dAll(vtkmodules.test.Testing.vtkTest):

    class Colors(object):
        '''
            Provides some wrappers for using color names.
        '''
        def __init__(self):
            '''
                Define a single instance of the NamedColors class here.
            '''
            self.namedColors = vtkNamedColors()

        def GetRGBColor(self, colorName):
            '''
                Return the red, green and blue components for a
                color as doubles.
            '''
            rgb = [0.0, 0.0, 0.0] # black
            self.namedColors.GetColorRGB(colorName, rgb)
            return rgb

        def GetRGBAColor(self, colorName):
            '''
                Return the red, green, blue and alpha
                components for a color as doubles.
            '''
            rgba = [0.0, 0.0, 0.0, 1.0] # black
            self.namedColors.GetColor(colorName, rgba)
            return rgba

    def testSync3dAll(self):

        # Create the RenderWindow, Renderer and both Actors
        #
        ren = vtkRenderer()
        renWin = vtkRenderWindow()
        renWin.AddRenderer(ren)

        # create pipeline
        #
        slc = vtkStructuredPointsReader()
        slc.SetFileName(VTK_DATA_ROOT + "/Data/ironProt.vtk")

        colors = ["flesh", "banana", "grey", "pink", "carrot", "gainsboro", "tomato", "gold", "thistle", "chocolate"]

        types = ["UnsignedChar", "Char", "Short", "UnsignedShort", "Int", "UnsignedInt", "Long", "UnsignedLong", "Float", "Double"]

        i = 1
        c = 0
        clip = list()
        cast = list()
        iso = list()
        mapper = list()
        actor = list()

        colorWrapper = self.Colors()

        for idx, vtkType in enumerate(types):
            clip.append(vtkImageClip())
            clip[idx].SetInputConnection(slc.GetOutputPort())
            clip[idx].SetOutputWholeExtent(-1000, 1000, -1000, 1000, i, i + 5)
            i += 5
            cast.append(vtkImageCast())
            eval('cast[idx].SetOutputScalarTypeTo' + vtkType + '()')
            cast[idx].SetInputConnection(clip[idx].GetOutputPort())
            cast[idx].ClampOverflowOn()

            iso.append(vtkSynchronizedTemplates3D())
            iso[idx].SetInputConnection(cast[idx].GetOutputPort())
            iso[idx].GenerateValues(1, 30, 30)

            mapper.append(vtkPolyDataMapper())
            mapper[idx].SetInputConnection(iso[idx].GetOutputPort())
            mapper[idx].ScalarVisibilityOff()

            actor.append(vtkActor())
            actor[idx].SetMapper(mapper[idx])
        #    actor[idx].Actor.GetProperty().SetDiffuseColor(lindex.colors.c.lindex.colors.c+1.lindex.colors.c+1)
            actor[idx].GetProperty().SetDiffuseColor(colorWrapper.GetRGBColor(colors[c]))
            actor[idx].GetProperty().SetSpecularPower(30)
            actor[idx].GetProperty().SetDiffuse(.7)
            actor[idx].GetProperty().SetSpecular(.5)
            c += 1
            ren.AddActor(actor[idx])


        outline = vtkOutlineFilter()
        outline.SetInputConnection(slc.GetOutputPort())
        outlineMapper = vtkPolyDataMapper()
        outlineMapper.SetInputConnection(outline.GetOutputPort())
        outlineActor = vtkActor()
        outlineActor.SetMapper(outlineMapper)
        outlineActor.VisibilityOff()

        # Add the actors to the renderer, set the background and size
        #
        ren.AddActor(outlineActor)
        ren.SetBackground(0.9, .9, .9)
        ren.ResetCamera()
        ren.GetActiveCamera().SetViewAngle(30)
        ren.GetActiveCamera().Elevation(20)
        ren.GetActiveCamera().Azimuth(20)
        ren.GetActiveCamera().Zoom(1.5)
        ren.ResetCameraClippingRange()

        renWin.SetSize(400, 400)

        # render and interact with data

        iRen = vtkRenderWindowInteractor()
        iRen.SetRenderWindow(renWin);
        renWin.Render()


        img_file = "sync3dAll.png"
        vtkmodules.test.Testing.compareImage(iRen.GetRenderWindow(), vtkmodules.test.Testing.getAbsImagePath(img_file))
        vtkmodules.test.Testing.interact()

if __name__ == "__main__":
     vtkmodules.test.Testing.main([(sync3dAll, 'test')])



#!/usr/bin/env python
from vtkmodules.vtkFiltersCore import vtkImageAppend
from vtkmodules.vtkIOImage import vtkImageReader
from vtkmodules.vtkImagingCore import (
    vtkImageCast,
    vtkImageFlip,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Image pipeline
reader = vtkImageReader()
reader.GetExecutive().SetReleaseDataFlag(0,0)
reader.SetDataByteOrderToLittleEndian()
reader.SetDataExtent(0,63,0,63,1,93)
reader.SetFilePrefix(VTK_DATA_ROOT + "/Data/headsq/quarter")
reader.SetDataMask(0x7fff)
imageFloat = vtkImageCast()
imageFloat.SetInputConnection(reader.GetOutputPort())
imageFloat.SetOutputScalarTypeToFloat()
flipX = vtkImageFlip()
flipX.SetInputConnection(imageFloat.GetOutputPort())
flipX.SetFilteredAxis(0)
flipY = vtkImageFlip()
flipY.SetInputConnection(imageFloat.GetOutputPort())
flipY.SetFilteredAxis(1)
flipY.FlipAboutOriginOn()
imageAppend = vtkImageAppend()
imageAppend.AddInputConnection(imageFloat.GetOutputPort())
imageAppend.AddInputConnection(flipX.GetOutputPort())
imageAppend.AddInputConnection(flipY.GetOutputPort())
imageAppend.SetAppendAxis(0)
viewer = vtkImageViewer()
viewer.SetInputConnection(imageAppend.GetOutputPort())
viewer.SetZSlice(22)
viewer.SetColorWindow(2000)
viewer.SetColorLevel(1000)
#make interface
viewer.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkMath,
    vtkPoints,
    vtkUnsignedCharArray,
)
from vtkmodules.vtkCommonDataModel import (
    vtkCellArray,
    vtkPolyData,
)
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersCore import (
    vtkAppendPolyData,
    vtkCleanPolyData,
    vtkFeatureEdges,
    vtkStripper,
    vtkTubeFilter,
)
from vtkmodules.vtkFiltersGeneral import vtkTransformPolyDataFilter
from vtkmodules.vtkFiltersModeling import vtkButterflySubdivisionFilter
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkPolyDataMapper,
    vtkProperty,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# On older Macs, 10 is too low. Due to what looks like a driver bug
# spectral lighting behaves sort of weird and produces small differences
threshold = 30
points = vtkPoints()
points.InsertNextPoint(2,4,0)
points.InsertNextPoint(2.6,2.6,0)
points.InsertNextPoint(4,2,0)
points.InsertNextPoint(1.4,4,1.4)
points.InsertNextPoint(2,3,1)
points.InsertNextPoint(3,2,1)
points.InsertNextPoint(4,1.4,1.4)
points.InsertNextPoint(0,4,2)
points.InsertNextPoint(1,3,2)
points.InsertNextPoint(2,2,2)
points.InsertNextPoint(3,1,2)
points.InsertNextPoint(4,0,2)
points.InsertNextPoint(0,2.6,2.6)
points.InsertNextPoint(1,2,3)
points.InsertNextPoint(2,1,3)
points.InsertNextPoint(2.6,0,2.6)
points.InsertNextPoint(0,2,4)
points.InsertNextPoint(1.4,1.4,4)
points.InsertNextPoint(2,0,4)
faces = vtkCellArray()
faces.InsertNextCell(3)
faces.InsertCellPoint(0)
faces.InsertCellPoint(3)
faces.InsertCellPoint(4)
faces.InsertNextCell(3)
faces.InsertCellPoint(0)
faces.InsertCellPoint(4)
faces.InsertCellPoint(1)
faces.InsertNextCell(3)
faces.InsertCellPoint(1)
faces.InsertCellPoint(4)
faces.InsertCellPoint(5)
faces.InsertNextCell(3)
faces.InsertCellPoint(1)
faces.InsertCellPoint(5)
faces.InsertCellPoint(2)
faces.InsertNextCell(3)
faces.InsertCellPoint(2)
faces.InsertCellPoint(5)
faces.InsertCellPoint(6)
faces.InsertNextCell(3)
faces.InsertCellPoint(3)
faces.InsertCellPoint(7)
faces.InsertCellPoint(8)
faces.InsertNextCell(3)
faces.InsertCellPoint(3)
faces.InsertCellPoint(8)
faces.InsertCellPoint(4)
faces.InsertNextCell(3)
faces.InsertCellPoint(4)
faces.InsertCellPoint(8)
faces.InsertCellPoint(9)
faces.InsertNextCell(3)
faces.InsertCellPoint(4)
faces.InsertCellPoint(9)
faces.InsertCellPoint(5)
faces.InsertNextCell(3)
faces.InsertCellPoint(5)
faces.InsertCellPoint(9)
faces.InsertCellPoint(10)
faces.InsertNextCell(3)
faces.InsertCellPoint(5)
faces.InsertCellPoint(10)
faces.InsertCellPoint(6)
faces.InsertNextCell(3)
faces.InsertCellPoint(6)
faces.InsertCellPoint(10)
faces.InsertCellPoint(11)
faces.InsertNextCell(3)
faces.InsertCellPoint(7)
faces.InsertCellPoint(12)
faces.InsertCellPoint(8)
faces.InsertNextCell(3)
faces.InsertCellPoint(8)
faces.InsertCellPoint(12)
faces.InsertCellPoint(13)
faces.InsertNextCell(3)
faces.InsertCellPoint(8)
faces.InsertCellPoint(13)
faces.InsertCellPoint(9)
faces.InsertNextCell(3)
faces.InsertCellPoint(9)
faces.InsertCellPoint(13)
faces.InsertCellPoint(14)
faces.InsertNextCell(3)
faces.InsertCellPoint(9)
faces.InsertCellPoint(14)
faces.InsertCellPoint(10)
faces.InsertNextCell(3)
faces.InsertCellPoint(10)
faces.InsertCellPoint(14)
faces.InsertCellPoint(15)
faces.InsertNextCell(3)
faces.InsertCellPoint(10)
faces.InsertCellPoint(15)
faces.InsertCellPoint(11)
faces.InsertNextCell(3)
faces.InsertCellPoint(12)
faces.InsertCellPoint(16)
faces.InsertCellPoint(13)
faces.InsertNextCell(3)
faces.InsertCellPoint(13)
faces.InsertCellPoint(16)
faces.InsertCellPoint(17)
faces.InsertNextCell(3)
faces.InsertCellPoint(13)
faces.InsertCellPoint(17)
faces.InsertCellPoint(14)
faces.InsertNextCell(3)
faces.InsertCellPoint(14)
faces.InsertCellPoint(17)
faces.InsertCellPoint(18)
faces.InsertNextCell(3)
faces.InsertCellPoint(14)
faces.InsertCellPoint(18)
faces.InsertCellPoint(15)
model = vtkPolyData()
model.SetPolys(faces)
model.SetPoints(points)
rn = vtkMath()
cellColors = vtkUnsignedCharArray()
cellColors.SetNumberOfComponents(3)
cellColors.SetNumberOfTuples(model.GetNumberOfCells())
i = 0
while i < model.GetNumberOfCells():
    cellColors.InsertComponent(i,0,rn.Random(100,255))
    cellColors.InsertComponent(i,1,rn.Random(100,255))
    cellColors.InsertComponent(i,2,rn.Random(100,255))
    i = i + 1

model.GetCellData().SetScalars(cellColors)
t0 = vtkTransform()
t0.Identity()
tf0 = vtkTransformPolyDataFilter()
tf0.SetTransform(t0)
tf0.SetInputData(model)
t1 = vtkTransform()
t1.Identity()
t1.RotateZ(90)
tf1 = vtkTransformPolyDataFilter()
tf1.SetTransform(t1)
tf1.SetInputData(model)
t2 = vtkTransform()
t2.Identity()
t2.RotateZ(180)
tf2 = vtkTransformPolyDataFilter()
tf2.SetTransform(t2)
tf2.SetInputData(model)
t3 = vtkTransform()
t3.Identity()
t3.RotateZ(270)
tf3 = vtkTransformPolyDataFilter()
tf3.SetTransform(t3)
tf3.SetInputData(model)
af = vtkAppendPolyData()
af.AddInputConnection(tf0.GetOutputPort())
af.AddInputConnection(tf1.GetOutputPort())
af.AddInputConnection(tf2.GetOutputPort())
af.AddInputConnection(tf3.GetOutputPort())
t4 = vtkTransform()
t4.Identity()
t4.RotateX(180)
tf4 = vtkTransformPolyDataFilter()
tf4.SetTransform(t4)
tf4.SetInputConnection(af.GetOutputPort())
af2 = vtkAppendPolyData()
af2.AddInputConnection(af.GetOutputPort())
af2.AddInputConnection(tf4.GetOutputPort())
t5 = vtkTransform()
t5.Identity()
t5.Translate(0,0,-8)
tf5 = vtkTransformPolyDataFilter()
tf5.SetTransform(t5)
tf5.SetInputConnection(af2.GetOutputPort())
af3 = vtkAppendPolyData()
af3.AddInputConnection(af2.GetOutputPort())
af3.AddInputConnection(tf5.GetOutputPort())
t6 = vtkTransform()
t6.Identity()
t6.Translate(0,-8,0)
tf6 = vtkTransformPolyDataFilter()
tf6.SetTransform(t6)
tf6.SetInputConnection(af3.GetOutputPort())
af4 = vtkAppendPolyData()
af4.AddInputConnection(af3.GetOutputPort())
af4.AddInputConnection(tf6.GetOutputPort())
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
clean = vtkCleanPolyData()
clean.SetTolerance(.001)
clean.SetInputData(model)
clean.SetInputConnection(af2.GetOutputPort())
clean.SetInputConnection(af3.GetOutputPort())
clean.SetInputConnection(af4.GetOutputPort())
subdivide = vtkButterflySubdivisionFilter()
subdivide.SetInputConnection(clean.GetOutputPort())
subdivide.SetNumberOfSubdivisions(3)
mapper = vtkDataSetMapper()
mapper.SetInputConnection(subdivide.GetOutputPort())
surface = vtkActor()
surface.SetMapper(mapper)
fe = vtkFeatureEdges()
fe.SetInputConnection(subdivide.GetOutputPort())
fe.SetFeatureAngle(100)
feStripper = vtkStripper()
feStripper.SetInputConnection(fe.GetOutputPort())
feTubes = vtkTubeFilter()
feTubes.SetInputConnection(feStripper.GetOutputPort())
feTubes.SetRadius(.1)
feMapper = vtkPolyDataMapper()
feMapper.SetInputConnection(feTubes.GetOutputPort())
edges = vtkActor()
edges.SetMapper(feMapper)
# Add the actors to the renderer, set the background and size
#
ren1.AddActor(surface)
ren1.AddActor(edges)
backP = vtkProperty()
backP.SetDiffuseColor(1,1,.3)
surface.SetBackfaceProperty(backP)
edges.GetProperty().SetDiffuseColor(.2,.2,.2)
surface.GetProperty().SetDiffuseColor(1,.4,.3)
surface.GetProperty().SetSpecular(.4)
surface.GetProperty().SetDiffuse(.8)
surface.GetProperty().SetSpecularPower(40)
ren1.SetBackground(0.1,0.2,0.4)
renWin.SetSize(300,300)
# render the image
#
ren1.ResetCamera()
cam1 = ren1.GetActiveCamera()
cam1.Azimuth(90)
ren1.ResetCamera()
cam1.Zoom(1.5)
iren.Initialize()
# prevent the tk window from showing up then start the event loop
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import vtkSphere
from vtkmodules.vtkImagingStencil import (
    vtkImageStencilToImage,
    vtkImplicitFunctionToImageStencil,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# A script to test converting a stencil to a binary image
sphere = vtkSphere()
sphere.SetCenter(128,128,0)
sphere.SetRadius(80)
functionToStencil = vtkImplicitFunctionToImageStencil()
functionToStencil.SetInput(sphere)
functionToStencil.SetOutputOrigin(0,0,0)
functionToStencil.SetOutputSpacing(1,1,1)
functionToStencil.SetOutputWholeExtent(0,255,0,255,0,0)
stencilToImage = vtkImageStencilToImage()
stencilToImage.SetInputConnection(functionToStencil.GetOutputPort())
stencilToImage.SetOutsideValue(0)
stencilToImage.SetInsideValue(255)
viewer = vtkImageViewer()
viewer.SetInputConnection(stencilToImage.GetOutputPort())
viewer.SetZSlice(0)
viewer.SetColorWindow(255)
viewer.SetColorLevel(127.5)
viewer.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkFiltersHybrid import vtkTemporalDataSetCache
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkIOEnSight import vtkGenericEnSightReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkGlyph3DMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create a rendering window and renderer
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
reader = vtkGenericEnSightReader()
reader.SetCaseFileName(VTK_DATA_ROOT + "/Data/EnSight/temporalCache.case")
tCache = vtkTemporalDataSetCache()
tCache.SetInputConnection(reader.GetOutputPort())
tCache.SetCacheSize(3)

# populate cache
tCache.UpdateTimeStep(0.0000)
tCache.UpdateTimeStep(0.010002)
tCache.UpdateTimeStep(0.020032)


# read through cache again
tCache.UpdateTimeStep(0.0000)
tCache.UpdateTimeStep(0.010002) # used to crash here

sphere = vtkSphereSource()
sphere.SetRadius(0.001)
mapper = vtkGlyph3DMapper()
mapper.SetInputConnection(tCache.GetOutputPort())
mapper.SetSourceConnection(sphere.GetOutputPort())
actor = vtkActor()
actor.SetMapper(mapper)
ren1.AddActor(actor)
ren1.ResetCamera()
iren.Initialize()
renWin.Render()

# Leaks without this line
reader.SetDefaultExecutivePrototype(None)



#!/usr/bin/env python
from vtkmodules.vtkFiltersCore import vtkContourFilter
from vtkmodules.vtkFiltersGeometry import vtkImageDataGeometryFilter
from vtkmodules.vtkFiltersHybrid import vtkImplicitModeller
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersSources import (
    vtkLineSource,
    vtkPlaneSource,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# this demonstrates appending data to generate an implicit model
lineX = vtkLineSource()
lineX.SetPoint1(-2.0,0.0,0.0)
lineX.SetPoint2(2.0,0.0,0.0)
lineX.Update()
lineY = vtkLineSource()
lineY.SetPoint1(0.0,-2.0,0.0)
lineY.SetPoint2(0.0,2.0,0.0)
lineY.Update()
lineZ = vtkLineSource()
lineZ.SetPoint1(0.0,0.0,-2.0)
lineZ.SetPoint2(0.0,0.0,2.0)
lineZ.Update()
aPlane = vtkPlaneSource()
aPlane.Update()
# set Data(0) "lineX"
# set Data(1) "lineY"
# set Data(2) "lineZ"
# set Data(3) "aPlane"
imp = vtkImplicitModeller()
imp.SetModelBounds(-2.5,2.5,-2.5,2.5,-2.5,2.5)
imp.SetSampleDimensions(60,60,60)
imp.SetCapValue(1000)
imp.SetProcessModeToPerVoxel()
# Okay now let's see if we can append
imp.StartAppend()
# for {set i 0} {$i < 4} {incr i} {
#     imp Append [$Data($i) GetOutput]
# }
imp.Append(lineX.GetOutput())
imp.Append(lineY.GetOutput())
imp.Append(lineZ.GetOutput())
imp.Append(aPlane.GetOutput())
imp.EndAppend()
cf = vtkContourFilter()
cf.SetInputConnection(imp.GetOutputPort())
cf.SetValue(0,0.1)
mapper = vtkPolyDataMapper()
mapper.SetInputConnection(cf.GetOutputPort())
actor = vtkActor()
actor.SetMapper(mapper)
outline = vtkOutlineFilter()
outline.SetInputConnection(imp.GetOutputPort())
outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())
outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)
plane = vtkImageDataGeometryFilter()
plane.SetInputConnection(imp.GetOutputPort())
plane.SetExtent(0,60,0,60,30,30)
planeMapper = vtkPolyDataMapper()
planeMapper.SetInputConnection(plane.GetOutputPort())
planeMapper.SetScalarRange(0.197813,0.710419)
planeActor = vtkActor()
planeActor.SetMapper(planeMapper)
# graphics stuff
ren1 = vtkRenderer()
ren1.AddActor(actor)
ren1.AddActor(planeActor)
ren1.AddActor(outlineActor)
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
ren1.SetBackground(0.1,0.2,0.4)
renWin.Render()
ren1.GetActiveCamera().Azimuth(30)
ren1.GetActiveCamera().Elevation(30)
ren1.ResetCameraClippingRange()
renWin.Render()
# --- end of script --



#!/usr/bin/env python3

from vtkmodules.test import Testing as vtkTesting
from vtkmodules.util.misc import vtkGetDataRoot
from pathlib import Path


VTK_DATA_ROOT = vtkGetDataRoot()
EXPORT_STATE = False

class TestScalarBarWidget(vtkTesting.vtkTest):

    def test(self):
        from vtkmodules import vtkInteractionStyle as _
        from vtkmodules import vtkRenderingOpenGL2 as _
        from vtkmodules.vtkCommonColor import vtkNamedColors
        from vtkmodules.vtkCommonCore import vtkLookupTable
        from vtkmodules.vtkIOLegacy import vtkUnstructuredGridReader
        from vtkmodules.vtkInteractionWidgets import vtkScalarBarWidget
        from vtkmodules.vtkRenderingAnnotation import vtkScalarBarActor
        from vtkmodules.vtkRenderingCore import (
            vtkActor,
            vtkDataSetMapper,
            vtkRenderWindow,
            vtkRenderWindowInteractor,
            vtkRenderer
        )
        from vtkmodules.vtkSerializationManager import vtkObjectManager

        self.id_rwi = ""

        def serialize():

            manager = vtkObjectManager()
            manager.Initialize()

            colors = vtkNamedColors()

            # The source file
            file_name = VTK_DATA_ROOT + "/Data/uGridEx.vtk"

            # Create a custom lut. The lut is used for both at the mapper and at the
            # scalar_bar
            lut = vtkLookupTable()
            lut.Build()

            # Read the source file.
            reader = vtkUnstructuredGridReader()
            reader.SetFileName(file_name)
            reader.Update()  # Needed because of GetScalarRange
            output = reader.GetOutput()
            scalar_range = output.GetScalarRange()

            mapper = vtkDataSetMapper()
            mapper.SetInputData(output)
            mapper.SetScalarRange(scalar_range)
            mapper.SetLookupTable(lut)

            actor = vtkActor()
            actor.SetMapper(mapper)

            renderer = vtkRenderer()
            renderer.AddActor(actor)
            renderer.SetBackground(colors.GetColor3d('MidnightBLue'))

            render_window = vtkRenderWindow()
            render_window.AddRenderer(renderer)
            render_window.SetSize(300, 300)
            render_window.SetWindowName("ScalarBarWidget")

            interactor = vtkRenderWindowInteractor()
            interactor.SetRenderWindow(render_window)

            # create the scalar_bar
            scalar_bar = vtkScalarBarActor()
            scalar_bar.SetOrientationToHorizontal()
            scalar_bar.SetLookupTable(lut)

            # create the scalar_bar_widget
            scalar_bar_widget = vtkScalarBarWidget()
            scalar_bar_widget.SetInteractor(interactor)
            scalar_bar_widget.SetScalarBarActor(scalar_bar)
            scalar_bar_widget.On()

            interactor.Initialize()
            render_window.Render()
            renderer.GetActiveCamera().SetPosition(-6.4, 10.3, 1.4)
            renderer.GetActiveCamera().SetFocalPoint(1.0, 0.5, 3.0)
            renderer.GetActiveCamera().SetViewUp(0.6, 0.4, -0.7)
            render_window.Render()
            self.id_rwi = manager.RegisterObject(interactor)
            _ = manager.RegisterObject(scalar_bar_widget)
            manager.UpdateStatesFromObjects()
            if EXPORT_STATE:
                # Saves state to scalar-bar-widget.states.json file and blobs in scalar-bar-widget.blobs.json file
                manager.Export("scalar-bar-widget")
            active_ids = manager.GetAllDependencies(0)

            states = map(manager.GetState, active_ids)
            hash_to_blob_map = { blob_hash: manager.GetBlob(blob_hash, True) for blob_hash in manager.GetBlobHashes(active_ids) }
            return states, hash_to_blob_map

        def deserialize(states, hash_to_blob_map):
            global id_rwi

            manager = vtkObjectManager()
            manager.Initialize()
            for state in states:
                manager.RegisterState(state)
            for hash_text, blob in hash_to_blob_map.items():
                manager.RegisterBlob(hash_text, blob)

            manager.UpdateObjectsFromStates()
            interactor = manager.GetObjectAtId(self.id_rwi)
            interactor.render_window.Render()
            vtkTesting.compareImage(interactor.render_window, Path(vtkTesting.getAbsImagePath(f"{__class__.__name__}.png")).as_posix())

        deserialize(*serialize())


if __name__ == "__main__":
    vtkTesting.main([(TestScalarBarWidget, 'test')])



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import vtkSphere
from vtkmodules.vtkFiltersCore import (
    vtkCellDataToPointData,
    vtkPointDataToCellData,
    vtkSimpleElevationFilter,
)
from vtkmodules.vtkFiltersExtraction import vtkExtractGeometry
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Test the fast paths in vtkCellDataToPointData
# Create three side-by-side windows to compare
# the results on polydata and unstructured grid.

# Control test resolution
res = 20

# Create the RenderWindow, Renderer and RenderWindowInteractor
ren0 = vtkRenderer()
ren0.SetViewport(0,0,0.33,1.0)
ren1 = vtkRenderer()
ren1.SetViewport(0.33,0,0.66,1.0)
ren2 = vtkRenderer()
ren2.SetViewport(0.66,0,1.0,1.0)
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)
renWin.AddRenderer(ren1)
renWin.AddRenderer(ren2)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create a sphere with cell data
sphere = vtkSphereSource()
sphere.SetThetaResolution(res)
sphere.SetPhiResolution(int(res/2))
sphere.GenerateNormalsOff()

ele = vtkSimpleElevationFilter()
ele.SetInputConnection(sphere.GetOutputPort())

pd2cd = vtkPointDataToCellData()
pd2cd.SetInputConnection(ele.GetOutputPort())
pd2cd.PassPointDataOff()

m0 = vtkPolyDataMapper()
m0.SetInputConnection(pd2cd.GetOutputPort())

a0 = vtkActor()
a0.SetMapper(m0)


# Now test on polydata
cd2pd1 = vtkCellDataToPointData()
cd2pd1.SetInputConnection(pd2cd.GetOutputPort())

m1 = vtkPolyDataMapper()
m1.SetInputConnection(cd2pd1.GetOutputPort())

a1 = vtkActor()
a1.SetMapper(m1)

# Now test on unstructured grid
impFunc = vtkSphere()
impFunc.SetCenter(0,0,0)
impFunc.SetRadius(10000000)
extract = vtkExtractGeometry()
extract.SetImplicitFunction(impFunc)
extract.SetInputConnection(pd2cd.GetOutputPort())
extract.ExtractInsideOn()
extract.Update()

cd2pd2 = vtkCellDataToPointData()
cd2pd2.SetInputConnection(extract.GetOutputPort())

m2 = vtkDataSetMapper()
m2.SetInputConnection(cd2pd2.GetOutputPort())

a2 = vtkActor()
a2.SetMapper(m2)

# Add the actors to the renderer, set the background and size
ren0.AddActor(a0)
ren0.SetBackground(0.1,0.2,0.4)
ren1.AddActor(a1)
ren1.SetBackground(0.1,0.2,0.4)
ren2.AddActor(a2)
ren2.SetBackground(0.1,0.2,0.4)
renWin.SetSize(600,200)

ren0.GetActiveCamera().SetPosition(1,0,0)
ren0.GetActiveCamera().SetFocalPoint(0,0,0)
ren0.ResetCamera()
ren1.SetActiveCamera(ren0.GetActiveCamera())
ren2.SetActiveCamera(ren0.GetActiveCamera())

# render the image
iren.Initialize()
iren.Start()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImport import vtkVRMLImporter
from vtkmodules.vtkRenderingCore import (
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
importer = vtkVRMLImporter()
importer.SetRenderWindow(renWin)
importer.SetFileName(VTK_DATA_ROOT + "/Data/bot2.wrl")
importer.Update()
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
importer.GetRenderer().SetBackground(0.1,0.2,0.4)
importer.GetRenderWindow().SetSize(300,300)
#
# the importer created the renderer
renCollection = renWin.GetRenderers()
renCollection.InitTraversal()
ren = renCollection.GetNextItem()
#
# change view up to +z
#
ren.GetActiveCamera().SetPosition(-3.25303,3.46205,3.15906)
ren.GetActiveCamera().SetFocalPoint(0,0,0)
ren.GetActiveCamera().SetViewUp(0.564063,0.825024,-0.0341876)
#
# let the renderer compute good position and focal point
#
ren.ResetCamera()
ren.GetActiveCamera().Dolly(1.75)
ren1.ResetCameraClippingRange()
# render the image
#
iren.Initialize()
# --- end of script --



#!/usr/bin/env python

"""This test ensures that the mapper does not change the LookupTable
that may be shared among different mappers.  Specifically, the vtkMapper
and vtkScalarsToColorsPainter classes use the LookupTable to map scalars
to colors.  When they do this they set the LookupTable's Alpha ivar.
They should do it in a manner that the LUT's original value is reset.
If this is not done strange errors show up.  For example if you use an
ImagePlaneWidget and share its LUT with another mapper that has either a
different opacity, then the image plane widget will pick up the wrong
opacity leading to subtle errors.  This test ensures that this does not
happen by testing MapScalars explicitly and also by creating an
ImagePlaneWidget.  """

import os
import os.path
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkLookupTable,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import vtkPolyData
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkIOImage import vtkVolume16Reader
from vtkmodules.vtkInteractionWidgets import vtkImagePlaneWidget
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCellPicker,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.test import Testing
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

class TestMapperLUT(Testing.vtkTest):
    def testMapScalars(self):
        """Test if the mapper sets the Alpha of the LUT."""
        # Create dummy data.
        p = vtkPolyData()
        pts = vtkPoints()
        pts.InsertNextPoint((0,0,0))
        sc = vtkFloatArray()
        sc.InsertNextValue(10.0)
        p.SetPoints(pts)
        p.GetPointData().SetScalars(sc)
        l = vtkLookupTable()
        m = vtkPolyDataMapper()
        m.SetInputData(p)
        m.SetScalarRange(0.0, 10.0)
        m.SetLookupTable(l)
        ret = m.MapScalars(0.5)
        self.assertEqual(l.GetAlpha(), 1.0)

    def testImagePlaneWidget(self):
        "A more rigorous test using the image plane widget."
        # This test is largely copied from
        # Widgets/Python/TestImagePlaneWidget.py

        # Load some data.
        v16 = vtkVolume16Reader()
        v16.SetDataDimensions(64, 64)
        v16.SetDataByteOrderToLittleEndian()
        v16.SetFilePrefix(os.path.join(VTK_DATA_ROOT,
                                       "Data", "headsq", "quarter"))
        v16.SetImageRange(1, 93)
        v16.SetDataSpacing(3.2, 3.2, 1.5)
        v16.Update()

        xMin, xMax, yMin, yMax, zMin, zMax = v16.GetExecutive().GetWholeExtent(v16.GetOutputInformation(0))
        img_data = v16.GetOutput()
        spacing = img_data.GetSpacing()
        sx, sy, sz = spacing

        origin = img_data.GetOrigin()
        ox, oy, oz = origin

        # An outline is shown for context.
        outline = vtkOutlineFilter()
        outline.SetInputData(img_data)

        outlineMapper = vtkPolyDataMapper()
        outlineMapper.SetInputConnection(outline.GetOutputPort())

        outlineActor = vtkActor()
        outlineActor.SetMapper(outlineMapper)

        # The shared picker enables us to use 3 planes at one time
        # and gets the picking order right
        picker = vtkCellPicker()
        picker.SetTolerance(0.005)

        # The 3 image plane widgets are used to probe the dataset.
        planeWidgetX = vtkImagePlaneWidget()
        planeWidgetX.DisplayTextOn()
        planeWidgetX.SetInputData(img_data)
        planeWidgetX.SetPlaneOrientationToXAxes()
        planeWidgetX.SetSliceIndex(32)
        planeWidgetX.SetPicker(picker)
        planeWidgetX.SetKeyPressActivationValue("x")
        prop1 = planeWidgetX.GetPlaneProperty()
        prop1.SetColor(1, 0, 0)

        planeWidgetY = vtkImagePlaneWidget()
        planeWidgetY.DisplayTextOn()
        planeWidgetY.SetInputData(img_data)
        planeWidgetY.SetPlaneOrientationToYAxes()
        planeWidgetY.SetSliceIndex(32)
        planeWidgetY.SetPicker(picker)
        planeWidgetY.SetKeyPressActivationValue("y")
        prop2 = planeWidgetY.GetPlaneProperty()
        prop2.SetColor(1, 1, 0)
        planeWidgetY.SetLookupTable(planeWidgetX.GetLookupTable())

        # for the z-slice, turn off texture interpolation:
        # interpolation is now nearest neighbour, to demonstrate
        # cross-hair cursor snapping to pixel centers
        planeWidgetZ = vtkImagePlaneWidget()
        planeWidgetZ.DisplayTextOn()
        planeWidgetZ.SetInputData(img_data)
        planeWidgetZ.SetPlaneOrientationToZAxes()
        planeWidgetZ.SetSliceIndex(46)
        planeWidgetZ.SetPicker(picker)
        planeWidgetZ.SetKeyPressActivationValue("z")
        prop3 = planeWidgetZ.GetPlaneProperty()
        prop3.SetColor(0, 0, 1)
        planeWidgetZ.SetLookupTable(planeWidgetX.GetLookupTable())

        # Now create another actor with an opacity < 1 and with some
        # scalars.
        p = vtkPolyData()
        pts = vtkPoints()
        pts.InsertNextPoint((0,0,0))
        sc = vtkFloatArray()
        sc.InsertNextValue(1.0)
        p.SetPoints(pts)
        p.GetPointData().SetScalars(sc)
        m = vtkPolyDataMapper()
        m.SetInputData(p)
        # Share the lookup table of the widgets.
        m.SetLookupTable(planeWidgetX.GetLookupTable())
        m.UseLookupTableScalarRangeOn()
        dummyActor = vtkActor()
        dummyActor.SetMapper(m)
        dummyActor.GetProperty().SetOpacity(0.0)

        # Create the RenderWindow and Renderer
        ren = vtkRenderer()
        renWin = vtkRenderWindow()
        renWin.SetMultiSamples(0)
        renWin.AddRenderer(ren)

        # Add the dummy actor.
        ren.AddActor(dummyActor)
        # Add the outline actor to the renderer, set the background
        # color and size
        ren.AddActor(outlineActor)
        renWin.SetSize(600, 600)
        ren.SetBackground(0.1, 0.1, 0.2)

        current_widget = planeWidgetZ
        mode_widget = planeWidgetZ

        # Set the interactor for the widgets
        iact = vtkRenderWindowInteractor()
        iact.SetRenderWindow(renWin)
        planeWidgetX.SetInteractor(iact)
        planeWidgetX.On()
        planeWidgetY.SetInteractor(iact)
        planeWidgetY.On()
        planeWidgetZ.SetInteractor(iact)
        planeWidgetZ.On()

        # Create an initial interesting view
        ren.ResetCamera();
        cam1 = ren.GetActiveCamera()
        cam1.Elevation(110)
        cam1.SetViewUp(0, 0, -1)
        cam1.Azimuth(45)
        ren.ResetCameraClippingRange()

        iact.Initialize()
        renWin.Render()

if __name__ == "__main__":
    Testing.main([(TestMapperLUT, 'test')])




#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkIdList,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    VTK_HEXAHEDRON,
    VTK_QUADRATIC_HEXAHEDRON,
    vtkHexahedron,
    vtkPixel,
    vtkPyramid,
    vtkQuad,
    vtkTriangle,
    vtkUnstructuredGrid,
    vtkVoxel,
    vtkWedge,
)
from vtkmodules.vtkFiltersCore import (
    vtkContour3DLinearGrid,
    vtkSimpleElevationFilter,
)
from vtkmodules.vtkFiltersSources import vtkCellTypeSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2

# Test filter input validity check on datasets with linear and nonlinear cells
linearCells = vtkCellTypeSource()
linearCells.SetCellType(VTK_HEXAHEDRON)
linearCells.Update()
assert(vtkContour3DLinearGrid.CanFullyProcessDataObject(linearCells.GetOutput(), 'DistanceToCenter'))

# Test filter input validity check on datasets with linear and nonlinear cells
quadraticCells = vtkCellTypeSource()
quadraticCells.SetCellType(VTK_QUADRATIC_HEXAHEDRON)
quadraticCells.Update()
assert(not vtkContour3DLinearGrid.CanFullyProcessDataObject(quadraticCells.GetOutput(), 'DistanceToCenter'))

# Test vtkContour3DLinearGrid on mixed cell types as well as on wedges and
# pyramids.

# Control test parameters
mergePoints = 1
interpolateAttr = 1
computeNormals = 1

# Manually create an unstructured grid with a mix of cells.  We have: quad;
# 3x3x3 volume; triangle; 3x3x3 structured grid; pixel; pyramid; wedge. Total
# of 76 points, 21 cells.
ugrid = vtkUnstructuredGrid()
pts = vtkPoints()
pts.SetNumberOfPoints(76)
ugrid.SetPoints(pts)
pts.SetPoint(0, 0,0,0)
pts.SetPoint(1, 2,0,0)
pts.SetPoint(2, 0,2,0)
pts.SetPoint(3, 2,2,0)

pts.SetPoint(4,  4,0,-1)
pts.SetPoint(5,  5,0,-1)
pts.SetPoint(6,  6,0,-1)
pts.SetPoint(7,  4,1,-1)
pts.SetPoint(8,  5,1,-1)
pts.SetPoint(9,  6,1,-1)
pts.SetPoint(10, 4,2,-1)
pts.SetPoint(11, 5,2,-1)
pts.SetPoint(12, 6,2,-1)
pts.SetPoint(13, 4,0,0)
pts.SetPoint(14, 5,0,0)
pts.SetPoint(15, 6,0,0)
pts.SetPoint(16, 4,1,0)
pts.SetPoint(17, 5,1,0)
pts.SetPoint(18, 6,1,0)
pts.SetPoint(19, 4,2,0)
pts.SetPoint(20, 5,2,0)
pts.SetPoint(21, 6,2,0)
pts.SetPoint(22, 4,0,1)
pts.SetPoint(23, 5,0,1)
pts.SetPoint(24, 6,0,1)
pts.SetPoint(25, 4,1,1)
pts.SetPoint(26, 5,1,1)
pts.SetPoint(27, 6,1,1)
pts.SetPoint(28, 4,2,1)
pts.SetPoint(29, 5,2,1)
pts.SetPoint(30, 6,2,1)

pts.SetPoint(31, 8,0,0)
pts.SetPoint(32, 10,0,0)
pts.SetPoint(33, 9,2,0)

pts.SetPoint(34, 12,0,-1)
pts.SetPoint(35, 13,0,-1)
pts.SetPoint(36, 14,0,-1)
pts.SetPoint(37, 12,1,-1)
pts.SetPoint(38, 13,1,-1)
pts.SetPoint(39, 14,1,-1)
pts.SetPoint(40, 12,2,-1)
pts.SetPoint(41, 13,2,-1)
pts.SetPoint(42, 14,2,-1)
pts.SetPoint(43, 12,0,0)
pts.SetPoint(44, 13,0,0)
pts.SetPoint(45, 14,0,0)
pts.SetPoint(46, 12,1,0)
pts.SetPoint(47, 13,1,0)
pts.SetPoint(48, 14,1,0)
pts.SetPoint(49, 12,2,0)
pts.SetPoint(50, 13,2,0)
pts.SetPoint(51, 14,2,0)
pts.SetPoint(52, 12,0,1)
pts.SetPoint(53, 13,0,1)
pts.SetPoint(54, 14,0,1)
pts.SetPoint(55, 12,1,1)
pts.SetPoint(56, 13,1,1)
pts.SetPoint(57, 14,1,1)
pts.SetPoint(58, 12,2,1)
pts.SetPoint(59, 13,2,1)
pts.SetPoint(60, 14,2,1)

pts.SetPoint(61, 16,0,0)
pts.SetPoint(62, 18,0,0)
pts.SetPoint(63, 16,2,0)
pts.SetPoint(64, 18,2,0)

pts.SetPoint(65, 20,0,-1)
pts.SetPoint(66, 22,0,-1)
pts.SetPoint(67, 20,2,-1)
pts.SetPoint(68, 22,2,-1)
pts.SetPoint(69, 21,1,1)

pts.SetPoint(70, 24,0,1)
pts.SetPoint(71, 26,0,1)
pts.SetPoint(72, 24,2,1)
pts.SetPoint(73, 26,2,1)
pts.SetPoint(74, 25,0,-1)
pts.SetPoint(75, 25,2,-1)

# Now populate cells
ids = vtkIdList()

# quad
quad = vtkQuad()
ids.SetNumberOfIds(4)
ids.SetId(0,0)
ids.SetId(1,1)
ids.SetId(2,3)
ids.SetId(3,2)
ugrid.InsertNextCell(quad.GetCellType(),ids)

# 8 voxels
vox = vtkVoxel()
ids.SetNumberOfIds(8)
ids.SetId(0,4)
ids.SetId(1,5)
ids.SetId(2,7)
ids.SetId(3,8)
ids.SetId(4,13)
ids.SetId(5,14)
ids.SetId(6,16)
ids.SetId(7,17)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,5)
ids.SetId(1,6)
ids.SetId(2,8)
ids.SetId(3,9)
ids.SetId(4,14)
ids.SetId(5,15)
ids.SetId(6,17)
ids.SetId(7,18)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,7)
ids.SetId(1,8)
ids.SetId(2,10)
ids.SetId(3,11)
ids.SetId(4,16)
ids.SetId(5,17)
ids.SetId(6,19)
ids.SetId(7,20)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,8)
ids.SetId(1,9)
ids.SetId(2,11)
ids.SetId(3,12)
ids.SetId(4,17)
ids.SetId(5,18)
ids.SetId(6,20)
ids.SetId(7,21)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,13)
ids.SetId(1,14)
ids.SetId(2,16)
ids.SetId(3,17)
ids.SetId(4,22)
ids.SetId(5,23)
ids.SetId(6,25)
ids.SetId(7,26)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,14)
ids.SetId(1,15)
ids.SetId(2,17)
ids.SetId(3,18)
ids.SetId(4,23)
ids.SetId(5,24)
ids.SetId(6,26)
ids.SetId(7,27)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,16)
ids.SetId(1,17)
ids.SetId(2,19)
ids.SetId(3,20)
ids.SetId(4,25)
ids.SetId(5,26)
ids.SetId(6,28)
ids.SetId(7,29)
ugrid.InsertNextCell(vox.GetCellType(),ids)

ids.SetId(0,17)
ids.SetId(1,18)
ids.SetId(2,20)
ids.SetId(3,21)
ids.SetId(4,26)
ids.SetId(5,27)
ids.SetId(6,29)
ids.SetId(7,30)
ugrid.InsertNextCell(vox.GetCellType(),ids)

# triangle
tri = vtkTriangle()
ids.SetNumberOfIds(3)
ids.SetId(0,31)
ids.SetId(1,32)
ids.SetId(2,33)
ugrid.InsertNextCell(tri.GetCellType(),ids)

# 8 hexes
hexa = vtkHexahedron()
ids.SetNumberOfIds(8)
ids.SetId(0,34)
ids.SetId(1,35)
ids.SetId(3,37)
ids.SetId(2,38)
ids.SetId(4,43)
ids.SetId(5,44)
ids.SetId(7,46)
ids.SetId(6,47)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,35)
ids.SetId(1,36)
ids.SetId(3,38)
ids.SetId(2,39)
ids.SetId(4,44)
ids.SetId(5,45)
ids.SetId(7,47)
ids.SetId(6,48)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,37)
ids.SetId(1,38)
ids.SetId(3,40)
ids.SetId(2,41)
ids.SetId(4,46)
ids.SetId(5,47)
ids.SetId(7,49)
ids.SetId(6,50)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,38)
ids.SetId(1,39)
ids.SetId(3,41)
ids.SetId(2,42)
ids.SetId(4,47)
ids.SetId(5,48)
ids.SetId(7,50)
ids.SetId(6,51)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,43)
ids.SetId(1,44)
ids.SetId(3,46)
ids.SetId(2,47)
ids.SetId(4,52)
ids.SetId(5,53)
ids.SetId(7,55)
ids.SetId(6,56)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,44)
ids.SetId(1,45)
ids.SetId(3,47)
ids.SetId(2,48)
ids.SetId(4,53)
ids.SetId(5,54)
ids.SetId(7,56)
ids.SetId(6,57)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,46)
ids.SetId(1,47)
ids.SetId(3,49)
ids.SetId(2,50)
ids.SetId(4,55)
ids.SetId(5,56)
ids.SetId(7,58)
ids.SetId(6,59)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

ids.SetId(0,47)
ids.SetId(1,48)
ids.SetId(3,50)
ids.SetId(2,51)
ids.SetId(4,56)
ids.SetId(5,57)
ids.SetId(7,59)
ids.SetId(6,60)
ugrid.InsertNextCell(hexa.GetCellType(),ids)

# pixel
pixel = vtkPixel()
ids.SetNumberOfIds(4)
ids.SetId(0,61)
ids.SetId(1,62)
ids.SetId(2,63)
ids.SetId(3,64)
ugrid.InsertNextCell(pixel.GetCellType(),ids)

# pyramid
pyr = vtkPyramid()
ids.SetNumberOfIds(5)
ids.SetId(0,65)
ids.SetId(1,66)
ids.SetId(2,68)
ids.SetId(3,67)
ids.SetId(4,69)
ugrid.InsertNextCell(pyr.GetCellType(),ids)

# wedge
wedge = vtkWedge()
ids.SetNumberOfIds(6)
ids.SetId(0,70)
ids.SetId(1,71)
ids.SetId(2,74)
ids.SetId(3,72)
ids.SetId(4,73)
ids.SetId(5,75)
ugrid.InsertNextCell(wedge.GetCellType(),ids)

# Now contour the cells
ele = vtkSimpleElevationFilter()
ele.SetInputData(ugrid)
ele.SetVector(0,1,0)

contour = vtkContour3DLinearGrid()
contour.SetInputConnection(ele.GetOutputPort())
contour.SetValue(0, 1)
contour.SetMergePoints(mergePoints)
contour.SetInterpolateAttributes(interpolateAttr);
contour.SetComputeNormals(computeNormals);
contour.Update()

contMapper = vtkPolyDataMapper()
contMapper.SetInputConnection(contour.GetOutputPort())
contMapper.ScalarVisibilityOff()

contActor = vtkActor()
contActor.SetMapper(contMapper)
contActor.GetProperty().SetColor(.8,.4,.4)

# Display the cells
cellMapper = vtkDataSetMapper()
cellMapper.SetInputData(ugrid)
cellMapper.ScalarVisibilityOff()

cellActor = vtkActor()
cellActor.SetMapper(cellMapper)
cellActor.GetProperty().SetColor(.8,.4,.4)
cellActor.GetProperty().SetRepresentationToWireframe()

# Define graphics objects
renWin = vtkRenderWindow()

ren1 = vtkRenderer()
ren1.SetBackground(1,1,1)
ren1.GetActiveCamera().SetFocalPoint(0,0,0)
ren1.GetActiveCamera().SetPosition(0,0.5,1)

renWin.AddRenderer(ren1)
renWin.SetSize(400,100)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren1.AddActor(contActor)
ren1.AddActor(cellActor)

renWin.Render()
ren1.ResetCamera()
ren1.GetActiveCamera().Zoom(3.5)

iren.Initialize()
iren.Start()
# --- end of script --



#!/usr/bin/env python
import sys
from vtkmodules.vtkCommonCore import (
    VTK_LINEAR_INTERPOLATION,
    vtkObjectFactory,
)
from vtkmodules.vtkCommonDataModel import vtkPiecewiseFunction
from vtkmodules.vtkIOImage import vtkNrrdReader
from vtkmodules.vtkRenderingCore import (
    vtkColorTransferFunction,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkShaderProperty,
    vtkVolume,
    vtkVolumeProperty,
)
from vtkmodules.vtkRenderingVolume import vtkGPUVolumeRayCastMapper
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.vtkRenderingVolumeOpenGL2
import vtkmodules.test.Testing
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

'''
  Prevent .pyc files from being created.
  Stops the vtk source being polluted
  by .pyc files.
'''
sys.dont_write_bytecode = True

# Disable object factory override for vtkNrrdReader
vtkObjectFactory.SetAllEnableFlags(False, "vtkNrrdReader", "vtkPNrrdReader")

reader = vtkNrrdReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/tooth.nhdr")
reader.Update()

volumeProperty = vtkVolumeProperty()
volumeProperty.ShadeOn()
volumeProperty.SetInterpolationType(VTK_LINEAR_INTERPOLATION)

range = reader.GetOutput().GetScalarRange()

# Prepare 1D Transfer Functions
ctf = vtkColorTransferFunction()
ctf.AddRGBPoint(0, 0.0, 0.0, 0.0)
ctf.AddRGBPoint(510, 0.4, 0.4, 1.0)
ctf.AddRGBPoint(640, 1.0, 1.0, 1.0)
ctf.AddRGBPoint(range[1], 0.9, 0.1, 0.1)

pf = vtkPiecewiseFunction()
pf.AddPoint(0, 0.00)
pf.AddPoint(510, 0.00)
pf.AddPoint(640, 0.5)
pf.AddPoint(range[1], 0.4)

volumeProperty.SetScalarOpacity(pf)
volumeProperty.SetColor(ctf)
volumeProperty.SetShade(1)

mapper = vtkGPUVolumeRayCastMapper()
mapper.SetInputConnection(reader.GetOutputPort())
mapper.SetUseJittering(1)

# Modify the shader to color based on the depth of the translucent voxel
shaderProperty = vtkShaderProperty()
shaderProperty.AddFragmentShaderReplacement(
    "//VTK::Base::Dec",      # Source string to replace
    True,                    # before the standard replacements
    "//VTK::Base::Dec"       # We still want the default
    "\n bool l_updateDepth;"
    "\n vec3 l_opaqueFragPos;",
    False                    # only do it once i.e. only replace the first match
)
shaderProperty.AddFragmentShaderReplacement(
    "//VTK::Base::Init",
    True,
    "//VTK::Base::Init\n"
    "\n l_updateDepth = true;"
    "\n l_opaqueFragPos = vec3(0.0);",
    False
)
shaderProperty.AddFragmentShaderReplacement(
    "//VTK::Base::Impl",
    True,
    "//VTK::Base::Impl"
    "\n    if(!g_skip && g_srcColor.a > 0.0 && l_updateDepth)"
    "\n      {"
    "\n      l_opaqueFragPos = g_dataPos;"
    "\n      l_updateDepth = false;"
    "\n      }",
    False
)
shaderProperty.AddFragmentShaderReplacement(
    "//VTK::RenderToImage::Exit",
    True,
    "//VTK::RenderToImage::Exit"
    "\n  if (l_opaqueFragPos == vec3(0.0))"
    "\n    {"
    "\n    fragOutput0 = vec4(0.0);"
    "\n    }"
    "\n  else"
    "\n    {"
    "\n    vec4 depthValue = in_projectionMatrix * in_modelViewMatrix *"
    "\n                      in_volumeMatrix[0] * in_textureDatasetMatrix[0] *"
    "\n                      vec4(l_opaqueFragPos, 1.0);"
    "\n    depthValue /= depthValue.w;"
    "\n    fragOutput0 = vec4(vec3(0.5 * (gl_DepthRange.far -"
    "\n                       gl_DepthRange.near) * depthValue.z + 0.5 *"
    "\n                      (gl_DepthRange.far + gl_DepthRange.near)), 1.0);"
    "\n    }",
    False
)

volume = vtkVolume()
volume.SetShaderProperty(shaderProperty)
volume.SetMapper(mapper)
volume.SetProperty(volumeProperty)

renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.SetSize(300, 300)

ren = vtkRenderer()
renWin.AddRenderer(ren)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren.AddVolume(volume)
ren.GetActiveCamera().Elevation(-60.0)
ren.ResetCamera()
ren.GetActiveCamera().Zoom(1.3)

renWin.Render()
iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonExecutionModel import vtkCompositeDataPipeline
from vtkmodules.vtkFiltersCore import vtkContourFilter
from vtkmodules.vtkIOEnSight import vtkGenericEnSightReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkHierarchicalPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create a rendering window and renderer
ren1 = vtkRenderer()
ren1.SetBackground(0,0,0)
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
renWin.SetSize(300,300)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# camera parameters
camera = ren1.GetActiveCamera()
camera.SetPosition(-54.8012,109.471,231.412)
camera.SetFocalPoint(33,33,33)
camera.SetViewUp(0.157687,0.942832,-0.293604)
camera.SetViewAngle(30)
camera.SetClippingRange(124.221,363.827)
reader = vtkGenericEnSightReader()
# Make sure all algorithms use the composite data pipeline
cdp = vtkCompositeDataPipeline()
reader.SetDefaultExecutivePrototype(cdp)
reader.SetCaseFileName(VTK_DATA_ROOT + "/Data/EnSight/ironProt_bin.case")
Contour0 = vtkContourFilter()
Contour0.SetInputConnection(reader.GetOutputPort())
Contour0.SetValue(0,200)
Contour0.SetComputeScalars(1)
mapper = vtkHierarchicalPolyDataMapper()
mapper.SetInputConnection(Contour0.GetOutputPort())
mapper.SetScalarRange(0,1)
mapper.SetScalarVisibility(1)
actor = vtkActor()
actor.SetMapper(mapper)
actor.GetProperty().SetRepresentationToSurface()
actor.GetProperty().SetInterpolationToGouraud()
ren1.AddActor(actor)
# enable user interface interactor
iren.Initialize()
# prevent the tk window from showing up then start the event loop
reader.SetDefaultExecutivePrototype(None)
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkImageReader
from vtkmodules.vtkImagingCore import vtkImageReslice
from vtkmodules.vtkRenderingCore import (
    vtkActor2D,
    vtkImageMapper,
    vtkRenderWindow,
    vtkRenderer,
)
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# this script tests vtkImageReslice with different interpolation modes,
# with the wrap-pad feature turned on
# Image pipeline
reader = vtkImageReader()
reader.ReleaseDataFlagOff()
reader.SetDataByteOrderToLittleEndian()
reader.SetDataExtent(0,63,0,63,1,93)
reader.SetDataSpacing(3.2,3.2,1.5)
reader.SetFilePrefix(VTK_DATA_ROOT + "/Data/headsq/quarter")
reader.SetDataMask(0x7fff)
reslice1 = vtkImageReslice()
reslice1.SetInputConnection(reader.GetOutputPort())
reslice1.WrapOn()
reslice1.SetInterpolationModeToCubic()
reslice1.SetOutputSpacing(2.0,2.0,1.5)
reslice1.SetOutputOrigin(-32,-32,40)
reslice1.SetOutputExtent(0,127,0,127,0,0)
reslice2 = vtkImageReslice()
reslice2.SetInputConnection(reader.GetOutputPort())
reslice2.WrapOn()
reslice2.SetInterpolationModeToLinear()
reslice2.SetOutputSpacing(2.0,2.0,1.5)
reslice2.SetOutputOrigin(-32,-32,40)
reslice2.SetOutputExtent(0,127,0,127,0,0)
reslice3 = vtkImageReslice()
reslice3.SetInputConnection(reader.GetOutputPort())
reslice3.WrapOn()
reslice3.SetInterpolationModeToNearestNeighbor()
reslice3.SetOutputSpacing(2.0,2.0,1.5)
reslice3.SetOutputOrigin(-32,-32,40)
reslice3.SetOutputExtent(0,127,0,127,0,0)
reslice4 = vtkImageReslice()
reslice4.SetInputConnection(reader.GetOutputPort())
reslice4.WrapOn()
reslice4.SetInterpolationModeToLinear()
reslice4.SetOutputSpacing(3.2,3.2,1.5)
reslice4.SetOutputOrigin(-102.4,-102.4,40)
reslice4.SetOutputExtent(0,127,0,127,0,0)
mapper1 = vtkImageMapper()
mapper1.SetInputConnection(reslice1.GetOutputPort())
mapper1.SetColorWindow(2000)
mapper1.SetColorLevel(1000)
mapper1.SetZSlice(0)
mapper2 = vtkImageMapper()
mapper2.SetInputConnection(reslice2.GetOutputPort())
mapper2.SetColorWindow(2000)
mapper2.SetColorLevel(1000)
mapper2.SetZSlice(0)
mapper3 = vtkImageMapper()
mapper3.SetInputConnection(reslice3.GetOutputPort())
mapper3.SetColorWindow(2000)
mapper3.SetColorLevel(1000)
mapper3.SetZSlice(0)
mapper4 = vtkImageMapper()
mapper4.SetInputConnection(reslice4.GetOutputPort())
mapper4.SetColorWindow(2000)
mapper4.SetColorLevel(1000)
mapper4.SetZSlice(0)
actor1 = vtkActor2D()
actor1.SetMapper(mapper1)
actor2 = vtkActor2D()
actor2.SetMapper(mapper2)
actor3 = vtkActor2D()
actor3.SetMapper(mapper3)
actor4 = vtkActor2D()
actor4.SetMapper(mapper4)
imager1 = vtkRenderer()
imager1.AddViewProp(actor1)
imager1.SetViewport(0.5,0.0,1.0,0.5)
imager2 = vtkRenderer()
imager2.AddViewProp(actor2)
imager2.SetViewport(0.0,0.0,0.5,0.5)
imager3 = vtkRenderer()
imager3.AddViewProp(actor3)
imager3.SetViewport(0.5,0.5,1.0,1.0)
imager4 = vtkRenderer()
imager4.AddViewProp(actor4)
imager4.SetViewport(0.0,0.5,0.5,1.0)
imgWin = vtkRenderWindow()
imgWin.AddRenderer(imager1)
imgWin.AddRenderer(imager2)
imgWin.AddRenderer(imager3)
imgWin.AddRenderer(imager4)
imgWin.SetSize(256,256)
imgWin.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkPNGReader
from vtkmodules.vtkImagingFourier import (
    vtkImageFFT,
    vtkImageFourierCenter,
)
from vtkmodules.vtkImagingMath import (
    vtkImageLogarithmicScale,
    vtkImageMagnitude,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer2
from vtkmodules.vtkRenderingCore import vtkRenderWindowInteractor
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This scripts shows a compressed spectrum of an image.
# Image pipeline
reader = vtkPNGReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/fullhead15.png")
fft = vtkImageFFT()
fft.SetInputConnection(reader.GetOutputPort())
fft.ReleaseDataFlagOff()
#fft DebugOn
magnitude = vtkImageMagnitude()
magnitude.SetInputConnection(fft.GetOutputPort())
magnitude.ReleaseDataFlagOff()
center = vtkImageFourierCenter()
center.SetInputConnection(magnitude.GetOutputPort())
compress = vtkImageLogarithmicScale()
compress.SetInputConnection(center.GetOutputPort())
compress.SetConstant(15)
viewer = vtkImageViewer2()
viewer.SetInputConnection(compress.GetOutputPort())
viewer.SetColorWindow(150)
viewer.SetColorLevel(170)
viewInt = vtkRenderWindowInteractor()
viewer.SetupInteractor(viewInt)
viewer.Render()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkPNGReader
from vtkmodules.vtkImagingFourier import (
    vtkImageButterworthLowPass,
    vtkImageFFT,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This script shows the result of an ideal lowpass filter in frequency space.
# Image pipeline
reader = vtkPNGReader()
reader.SetFileName(VTK_DATA_ROOT + "/Data/fullhead15.png")
fft = vtkImageFFT()
fft.SetDimensionality(2)
fft.SetInputConnection(reader.GetOutputPort())
#fft DebugOn
lowPass = vtkImageButterworthLowPass()
lowPass.SetInputConnection(fft.GetOutputPort())
lowPass.SetOrder(2)
lowPass.SetXCutOff(0.2)
lowPass.SetYCutOff(0.1)
lowPass.ReleaseDataFlagOff()
#lowPass DebugOn
viewer = vtkImageViewer()
viewer.SetInputConnection(lowPass.GetOutputPort())
viewer.SetColorWindow(10000)
viewer.SetColorLevel(5000)
#viewer DebugOn
viewer.Render()
# --- end of script --



#!/usr/bin/env python
# import os
from vtkmodules.vtkFiltersCore import vtkTriangleFilter
from vtkmodules.vtkFiltersExtraction import vtkExtractRectilinearGrid
from vtkmodules.vtkFiltersGeometry import vtkDataSetSurfaceFilter
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkIOLegacy import vtkRectilinearGridReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create pipeline - rectilinear grid
#
rgridReader = vtkRectilinearGridReader()
rgridReader.SetFileName(VTK_DATA_ROOT + "/Data/RectGrid2.vtk")

outline = vtkOutlineFilter()
outline.SetInputConnection(rgridReader.GetOutputPort())

mapper = vtkPolyDataMapper()
mapper.SetInputConnection(outline.GetOutputPort())

actor = vtkActor()
actor.SetMapper(mapper)

rgridReader.Update()

extract1 = vtkExtractRectilinearGrid()
extract1.SetInputConnection(rgridReader.GetOutputPort())
# extract1.SetVOI(0, 46, 0, 32, 0, 10)
extract1.SetVOI(23, 40, 16, 30, 9, 9)
extract1.SetSampleRate(2, 2, 1)
extract1.IncludeBoundaryOn()
extract1.Update()

surf1 = vtkDataSetSurfaceFilter()
surf1.SetInputConnection(extract1.GetOutputPort())

tris = vtkTriangleFilter()
tris.SetInputConnection(surf1.GetOutputPort())

mapper1 = vtkPolyDataMapper()
mapper1.SetInputConnection(tris.GetOutputPort())
mapper1.SetScalarRange(extract1.GetOutput().GetScalarRange())

actor1 = vtkActor()
actor1.SetMapper(mapper1)

# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# ren1.AddActor(actor)
ren1.AddActor(actor1)
renWin.SetSize(340, 400)

iren.Initialize()

# render the image
#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import (
    vtkPlane,
    vtkSphere,
)
from vtkmodules.vtkFiltersCore import (
    vtkCutter,
    vtkExecutionTimer,
    vtkPlaneCutter,
)
from vtkmodules.vtkFiltersGeneral import vtkImageDataToPointSet
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkIOXML import vtkXMLRectilinearGridReader
from vtkmodules.vtkImagingHybrid import vtkSampleFunction
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.test import Testing
from vtkmodules.util.misc import vtkGetDataRoot

VTK_DATA_ROOT = vtkGetDataRoot()

# Control debugging parameters
res = 50

# Create the RenderWindow, Renderers
ren0 = vtkRenderer()
ren1 = vtkRenderer()
ren2 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren0)
renWin.AddRenderer(ren1)
renWin.AddRenderer(ren2)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create a synthetic source: sample a sphere across a volume
sphere = vtkSphere()
sphere.SetCenter(0.0, 0.0, 0.0)
sphere.SetRadius(0.25)

sample = vtkSampleFunction()
sample.SetImplicitFunction(sphere)
sample.SetModelBounds(-0.5, 0.5, -0.5, 0.5, -0.5, 0.5)
sample.SetSampleDimensions(res, res, res)
sample.Update()

# Converts image data to structured grid
convert = vtkImageDataToPointSet()
convert.SetInputConnection(sample.GetOutputPort())
convert.Update()

cthvtr = vtkXMLRectilinearGridReader()
cthvtr.SetFileName(VTK_DATA_ROOT + "/Data/cth.vtr")
cthvtr.CellArrayStatus = ['Pressure', 'Void Volume Fraction', 'X Velocity', 'Y Velocity', 'Z Velocity',
                          'Volume Fraction for Armor Plate', 'Mass for Armor Plate', 'Volume Fraction for Body, Nose',
                          'Mass for Body, Nose']
cthvtr.Update()
input = cthvtr.GetOutput()

# Create a cutting plane
plane = vtkPlane()
plane.SetOrigin(input.GetCenter())
plane.SetNormal(1, 1, 1)

# First create the usual cutter
cutter = vtkCutter()
cutter.SetInputData(input)
cutter.SetCutFunction(plane)

cutterMapper = vtkPolyDataMapper()
cutterMapper.SetInputConnection(cutter.GetOutputPort())
cutterMapper.ScalarVisibilityOff()

cutterActor = vtkActor()
cutterActor.SetMapper(cutterMapper)
cutterActor.GetProperty().SetColor(1, 1, 1)

# Throw in an outline
outline = vtkOutlineFilter()
outline.SetInputData(input)

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)

# Now create the accelerated version.
sCutter = vtkPlaneCutter()
sCutter.SetInputData(input)
sCutter.SetPlane(plane)

sCutterMapper = vtkPolyDataMapper()
sCutterMapper.SetInputConnection(sCutter.GetOutputPort())
sCutterMapper.ScalarVisibilityOff()

sCutterActor = vtkActor()
sCutterActor.SetMapper(sCutterMapper)
sCutterActor.GetProperty().SetColor(1, 1, 1)

# Accelerated cutter without tree
snCutter = vtkPlaneCutter()
snCutter.SetInputData(input)
snCutter.SetPlane(plane)
snCutter.BuildTreeOff()

snCutterMapper = vtkPolyDataMapper()
snCutterMapper.SetInputConnection(snCutter.GetOutputPort())
snCutterMapper.ScalarVisibilityOff()

snCutterActor = vtkActor()
snCutterActor.SetMapper(snCutterMapper)
snCutterActor.GetProperty().SetColor(1, 1, 1)

outlineT = vtkOutlineFilter()
outlineT.SetInputData(input)

outlineMapperT = vtkPolyDataMapper()
outlineMapperT.SetInputConnection(outlineT.GetOutputPort())

outlineActorT = vtkActor()
outlineActorT.SetMapper(outlineMapperT)

# Time the execution of the filter w/out scalar tree
cutter_timer = vtkExecutionTimer()
cutter_timer.SetFilter(cutter)
cutter.Update()
CT = cutter_timer.GetElapsedWallClockTime()
print("vtkCutter:", CT)

# Time the execution of the filter w/o sphere tree
snCutter_timer = vtkExecutionTimer()
snCutter_timer.SetFilter(snCutter)
snCutter.Update()
ST = snCutter_timer.GetElapsedWallClockTime()
print("vtkPlaneCutter: Without sphere tree:", ST)

# Time the execution of the filter w/ sphere tree
sCutter_timer = vtkExecutionTimer()
sCutter_timer.SetFilter(sCutter)
sCutter.Update()
ST = sCutter_timer.GetElapsedWallClockTime()
print("vtkPlaneCutter: Build sphere tree + execute once:", ST)

sCutter_timer = vtkExecutionTimer()
sCutter_timer.SetFilter(sCutter)
plane.Modified()
sCutter.Update()
SC = sCutter_timer.GetElapsedWallClockTime()
print("vtkPlaneCutter: with prebuilt sphere-tree", SC)

# Add the actors to the renderer, set the background and size
ren0.AddActor(outlineActor)
ren0.AddActor(cutterActor)
ren1.AddActor(outlineActorT)
ren1.AddActor(sCutterActor)
ren2.AddActor(outlineActorT)
ren2.AddActor(snCutterActor)

ren0.SetBackground(0, 0, 0)
ren1.SetBackground(0, 0, 0)
ren2.SetBackground(0, 0, 0)
ren0.SetViewport(0, 0, 0.33, 1)
ren1.SetViewport(0.33, 0, 0.66, 1)
ren2.SetViewport(0.66, 0, 1, 1)
renWin.SetSize(900, 300)
ren0.ResetCamera()
ren1.ResetCamera()
ren2.ResetCamera()
iren.Initialize()

renWin.Render()
iren.Start()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkLookupTable,
    vtkMath,
)
from vtkmodules.vtkCommonSystem import vtkTimerLog
from vtkmodules.vtkFiltersCore import vtkContourFilter
from vtkmodules.vtkFiltersPoints import (
    vtkGaussianKernel,
    vtkPointInterpolator2D,
)
from vtkmodules.vtkFiltersSources import vtkPlaneSource
from vtkmodules.vtkIOImage import vtkDEMReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Parameters for debugging
res = 200
math = vtkMath()

# create pipeline: use terrain dataset. Just for kicks we'll treat the elevations
# as a "point cloud" and interpolate the elevation onto a plane.
#
# Read the data: a height field results
demReader = vtkDEMReader()
demReader.SetFileName(VTK_DATA_ROOT + "/Data/SainteHelens.dem")
demReader.Update()

lo = demReader.GetOutput().GetScalarRange()[0]
hi = demReader.GetOutput().GetScalarRange()[1]

bds = demReader.GetOutput().GetBounds()
center = demReader.GetOutput().GetCenter()

# Create a plane of onto which to map the elevation data
plane = vtkPlaneSource()
plane.SetResolution(res,res)
plane.SetOrigin(bds[0],bds[2],bds[4])
plane.SetPoint1(bds[1],bds[2],bds[4])
plane.SetPoint2(bds[0],bds[3],bds[4])
plane.Update()


# Gaussian kernel-------------------------------------------------------
gaussianKernel = vtkGaussianKernel()
gaussianKernel.SetSharpness(2)
gaussianKernel.SetRadius(200)

interp = vtkPointInterpolator2D()
interp.SetInputConnection(plane.GetOutputPort())
interp.SetSourceConnection(demReader.GetOutputPort())
interp.SetKernel(gaussianKernel)
interp.SetNullPointsStrategyToClosestPoint()
interp.GetLocator().SetNumberOfPointsPerBucket(1)
interp.InterpolateZOff()

# Time execution
timer = vtkTimerLog()
timer.StartTimer()
interp.Update()
timer.StopTimer()
time = timer.GetElapsedTime()
print("Interpolate Terrain Points (Gaussian): {0}".format(time))

scalarRange = interp.GetOutput().GetPointData().GetArray("Elevation").GetRange()

lut = vtkLookupTable()
lut.SetHueRange(0.6, 0)
lut.SetSaturationRange(1.0, 0)
lut.SetValueRange(0.5, 1.0)

intMapper = vtkPolyDataMapper()
intMapper.SetInputConnection(interp.GetOutputPort())
intMapper.SetScalarModeToUsePointFieldData()
intMapper.SelectColorArray("Elevation")
intMapper.SetScalarRange(scalarRange)
intMapper.SetLookupTable(lut)

intActor = vtkActor()
intActor.SetMapper(intMapper)

# Create some contours
cf = vtkContourFilter()
cf.SetInputConnection(interp.GetOutputPort())
cf.GenerateValues(20,scalarRange)

cfMapper = vtkPolyDataMapper()
cfMapper.SetInputConnection(cf.GetOutputPort())

cfActor = vtkActor()
cfActor.SetMapper(cfMapper)

# Create the RenderWindow, Renderer and both Actors
#
ren0 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Add the actors to the renderer, set the background and size
#
ren0.AddActor(intActor)
ren0.AddActor(cfActor)
ren0.SetBackground(0.1, 0.2, 0.4)

renWin.SetSize(300, 300)

cam = ren0.GetActiveCamera()
cam.SetFocalPoint(center)

fp = cam.GetFocalPoint()
cam.SetPosition(fp[0]+.2,fp[1]+.1,fp[2]+1)
ren0.ResetCamera()

iren.Initialize()

# render the image
#
renWin.Render()
iren.Start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os, os.path
import sys
from vtkmodules.vtkCommonCore import (
    vtkFileOutputWindow,
    vtkLogger,
)
from vtkmodules.vtkCommonDataModel import (
    vtkImageData,
    vtkPolyData,
    vtkRectilinearGrid,
    vtkStructuredGrid,
    vtkUnstructuredGrid,
)
from vtkmodules.vtkIOParallelXML import (
    vtkXMLPDataSetWriter,
    vtkXMLPImageDataWriter,
    vtkXMLPPolyDataWriter,
    vtkXMLPRectilinearGridWriter,
    vtkXMLPStructuredGridWriter,
    vtkXMLPUnstructuredGridWriter,
)
from vtkmodules.vtkIOXML import (
    vtkXMLDataSetWriter,
    vtkXMLImageDataReader,
    vtkXMLImageDataWriter,
    vtkXMLPImageDataReader,
    vtkXMLPolyDataReader,
    vtkXMLPolyDataWriter,
    vtkXMLPPolyDataReader,
    vtkXMLPRectilinearGridReader,
    vtkXMLPStructuredGridReader,
    vtkXMLPUnstructuredGridReader,
    vtkXMLRectilinearGridReader,
    vtkXMLRectilinearGridWriter,
    vtkXMLStructuredGridReader,
    vtkXMLStructuredGridWriter,
    vtkXMLUnstructuredGridReader,
    vtkXMLUnstructuredGridWriter,
)
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# List of types and corresponding file extensions.
types = [['ImageData', 'vti'],
         ['RectilinearGrid', 'vtr'],
         ['StructuredGrid', 'vts'],
         ['PolyData', 'vtp'],
         ['UnstructuredGrid', 'vtu']]

# We intentionally cause vtkErrorMacro calls to be made below.  Dump
# errors to a file to prevent a window from coming up.
fow = vtkFileOutputWindow()
fow.SetFileName("TestEmptyXMLErrors.txt")
fow.SetFlush(0)
fow.SetInstance(fow)

# Loguru will still send messages to stderr. Disable that.
vtkLogger.SetStderrVerbosity(vtkLogger.VERBOSITY_OFF)

# Prepare some test files.
f = open('emptyFile.vtk', 'wt')
f.close()
f = open('junkFile.vtk', 'wt')
f.write("v9np7598mapwcawoiur-,rjpmW9MJV28nun-q38ynq-9.8ugujqvt-8n3-nv8")
f.close()

# Test each writer/reader.
for t in types:
    type = t[0]
    ext = t[1]
    input = eval('vtk' + type + '()')

    writer = eval('vtkXML' + type + 'Writer()')
    writer.SetFileName('empty' + type + '.' + ext)
    sys.stdout.write('Attempting ' + type + ' write with no input.\n')
    writer.Write()
    sys.stdout.write('Attempting ' + type + ' write with empty input.\n')
    writer.SetInputData(input)
    writer.Write()

    reader = eval('vtkXML' + type + 'Reader()')
    reader.SetFileName('empty' + type + '.' + ext)
    sys.stdout.write('Attempting read from file with empty ' + type + '.\n')
    reader.Update()

    pwriter = eval('vtkXMLP' + type + 'Writer()')
    pwriter.SetFileName('emptyP' + type + '.p' + ext)
    sys.stdout.write('Attempting P' + type + ' write with no input.\n')
    pwriter.Write()
    sys.stdout.write('Attempting P' + type + ' write with empty input.\n')
    pwriter.SetInputData(input)
    pwriter.Write()

    preader = eval('vtkXMLP' + type + 'Reader()')
    preader.SetFileName('emptyP' + type + '.p' + ext)
    sys.stdout.write('Attempting read from file with empty P' + type + '.\n')
    preader.Update()

    reader.SetFileName("emptyFile.vtk")
    preader.SetFileName("emptyFile.vtk")

    sys.stdout.write('Attempting read ' + type + ' from empty file.\n')
    reader.Update()
    sys.stdout.write('Attempting read P' + type + ' from empty file.\n')
    preader.Update()

    reader.SetFileName("junkFile.vtk")
    preader.SetFileName("junkFile.vtk")

    sys.stdout.write('Attempting read ' + type + ' from junk file.\n')
    reader.Update()
    sys.stdout.write('Attempting read P' + type + ' from junk file.\n')
    preader.Update()

    del input
    del writer
    del reader
    del pwriter
    del preader

# Test the data set writers.
for t in types:
    type = t[0]
    ext = t[1]
    writer = vtkXMLDataSetWriter()
    pwriter = vtkXMLPDataSetWriter()
    input = eval('vtk' + type + '()')

    writer.SetFileName('empty' + type + 'DataSet.' + ext)
    sys.stdout.write('Attempting DataSet ' + type + ' write with no input.\n')
    writer.Write()
    sys.stdout.write('Attempting DataSet ' + type + ' write with empty input.\n')
    writer.SetInputData(input)
    writer.Write()

    pwriter.SetFileName('emptyP' + type + 'DataSet.p' + ext)
    sys.stdout.write('Attempting DataSet ' + type + ' write with no input.\n')
    pwriter.SetNumberOfPieces(1)
    pwriter.Write()
    sys.stdout.write('Attempting DataSet ' + type + ' write with empty input.\n')
    pwriter.SetInputData(input)
    pwriter.Write()

    del input
    del pwriter
    del writer

# Done with the file output window.
fow.SetInstance(None)
del fow

# Delete the test files.
for t in types:
    type = t[0]
    ext = t[1]

    os.remove('empty' + type + '.' + ext)
    os.remove('empty' + type + 'DataSet.' + ext)
    os.remove('emptyP' + type + '.p' + ext)
    assert not os.path.exists('emptyP' + type + '_0.' + ext)
    os.remove('emptyP' + type + 'DataSet.p' + ext)
    assert not os.path.exists('emptyP' + type + 'DataSet_0.' + ext)

os.remove('junkFile.vtk')
os.remove('emptyFile.vtk')
os.remove('TestEmptyXMLErrors.txt')



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkImageReader
from vtkmodules.vtkImagingCore import (
    vtkImageCast,
    vtkImageMagnify,
    vtkImageThreshold,
)
from vtkmodules.vtkImagingMath import vtkImageWeightedSum
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Image pipeline
reader = vtkImageReader()
reader.ReleaseDataFlagOff()
reader.SetDataByteOrderToLittleEndian()
reader.SetDataExtent(0, 63, 0, 63, 1, 93)
reader.SetFilePrefix(VTK_DATA_ROOT + "/Data/headsq/quarter")
reader.SetDataMask(0x7fff)

mag = vtkImageMagnify()
mag.SetInputConnection(reader.GetOutputPort())
mag.SetMagnificationFactors(4, 4, 1)

th = vtkImageThreshold()
th.SetInputConnection(mag.GetOutputPort())
th.SetReplaceIn(1)
th.SetReplaceOut(1)
th.ThresholdBetween(-1000, 1000)
th.SetOutValue(0)
th.SetInValue(2000)

cast = vtkImageCast()
cast.SetInputConnection(mag.GetOutputPort())
cast.SetOutputScalarTypeToFloat()

cast2 = vtkImageCast()
cast2.SetInputConnection(th.GetOutputPort())
cast2.SetOutputScalarTypeToFloat()

sum = vtkImageWeightedSum()
sum.AddInputConnection(cast.GetOutputPort())
sum.AddInputConnection(cast2.GetOutputPort())
sum.SetWeight(0, 10)
sum.SetWeight(1, 4)

viewer = vtkImageViewer()
viewer.SetInputConnection(sum.GetOutputPort())
viewer.SetZSlice(22)
viewer.SetColorWindow(1819)
viewer.SetColorLevel(939)
sum.SetWeight(0, 1)
# make interface
viewer.SetSize(256, 256)
viewer.Render()
